<?php namespace App\Http\Controllers;

use App\Client;
use App\EmailGateway;
use App\Http\Requests;
use App\invoices;
use App\tickets;
use App\Uploads;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;

class AdminController extends Controller {

    public function __construct(){
        $this->beforeFilter('csrf',array('on'=>'post'));
    }


    public function dashboard(){

        $cl_count=Client::all()->count();
        $cl=Client::take('5')->orderBy('id','desc')->get();

        $inv_count=invoices::all()->count();
        $inv=invoices::take('10')->orderBy('id','desc')->get();

        $st_count=tickets::all()->count();
        $st=tickets::take('10')->orderBy('id','desc')->get();

        $uploads=Uploads::take('5')->orderBy('id','desc')->get();

        $post_size = trim(ini_get('post_max_size'));

        $sys_menu='Dashboard';

        return view('admin.dashboard',compact('cl_count','cl','inv_count','inv','st_count','st','post_size','uploads','sys_menu'));
    }

    public function login(){
        if ( \Auth::admin()->check() ) {
            return redirect('admin/dashboard');
        } else {
            return view('admin.landing-page');
        }
    }


    public function index(){
        if(\Auth::admin()->check()){
            return $this->dashboard();
        } else {
            return redirect('admin');
        }
    }

    public function getLogin(Request $request){
        $this->validate($request,[
            'email'=>'required','password'=>'required',
        ]);

        $check_input=$request->only('email','password');

        $public_path=public_path();
        $store_path=storage_path();
        if(is_writable($public_path)==false) {
            @chmod($public_path,755);
        }
        if(is_writable($store_path)==false){
            @chmod($store_path,755);
        }

        $remember = (Input::has('remember')) ? true : false;

        if(\Auth::admin()->attempt($check_input,$remember)){
            return response()->json([
                'validation'    => true,
                'url'           => url().'/admin/dashboard'
            ]);
        } else {
            return response()->json([
                'validation'    => false,
                'message'       => 'Invalid Email or Password'
            ]);
        }

    }


    public  function logout(){
        \Auth::admin()->logout();
        return redirect('admin')->with(['message'=>'Logout Successfully']);
    }

    /* editProfile  Function Start Here */
    public function editProfile()
    {
        $sys_menu='Edit Profile';
        $user=_info(\Auth::admin()->user()->id);
        return view('admin.edit-profile',compact('user','sys_menu'));
    }

    /* postEditProfile  Function Start Here */
    public function postEditProfile(Request $request)
    {

        $appStage=app_config('AppStage');
        if($appStage=='Demo'){
            return redirect('admin/edit-profile')->with([
                'message' => 'This Option Is Disable In Demo Mode',
                'message_important' => true
            ]);

            exit;
        }

        $v=\Validator::make($request->all(),[
            'full_name'=>'required','email'=>'required'
        ]);

        if($v->fails()){
            return redirect('admin/edit-profile')->withErrors($v->errors());
        }

        $full_name=Input::get('full_name');
        $email=Input::get('email');
        $password=Input::get('password');

        $profile_image=Input::file('profile_image');


        $exit_image=\Auth::admin()->user()->image;


        if($profile_image!=''){
            $destination = public_path() . '/assets/img/';
            $img = \Request::file('profile_image');
            $img_name=$img->getClientOriginalName();

            if ($img_name != '') {
                $save_path = 'assets/img/' . $img_name;
                Input::file('profile_image')->move($destination, $img_name);
            }else{
                $save_path=$exit_image;
            }
        }else{
            $save_path=$exit_image;
        }


        $uid=\Auth::admin()->user()->id;

        $d=User::find($uid);

        if ($email != '') {
            if ($email!=$d->email) {
                $exit=\DB::table('users')->where('email',$email)->first();
                if($exit){
                  return redirect('admin/edit-profile')->with([
                      'message'=>'This Email Address Already Registered With Another Email',
                      'message_important'=>true
                  ]);
                }
            }
        }

        if($password!=''){
            $password=\Hash::make($password);
        }else{
            $password=$d->password;
        }

        $d->name=$full_name;
        $d->email=$email;
        $d->password=$password;
        $d->image=$save_path;
        $d->save();

        return redirect('admin/edit-profile')->with([
            'message'=>'Profile Updated Successfully'
        ]);

    }



    /* forgotPassword  Function Start Here */
    public function forgotPassword()
    {
        return view('admin.landing-page');
    }


    /* forgotPasswordToken  Function Start Here */
    public function forgotPasswordToken(Request $request)
    {

        $appStage=app_config('AppStage');
        if($appStage=='Demo'){
            return redirect('admin')->with([
                'message'=>'This Option is Disable In Demo Mode',
                'message_important'=>true
            ]);
        }

        $v=\Validator::make($request->all(),[
            'email'=>'required'
        ]);

        if($v->fails()){
            return redirect('admin')->withErrors($v->errors());
        }

        $email=Input::get('email');

        $d=User::where('email','=',$email)->count();
        if($d=='1'){
            $fprand=substr(str_shuffle(str_repeat('0123456789','16')),0,'16');
            $fptime = time()+3600;

            $ef=User::where('email','=',$email)->first();
            $name=$ef->name;

            $ef->pwresetkey = $fprand;
            $ef->pwresetexpiry = $fptime;
            $ef->save();

            $ip=\Request::getClientIp();


            /*For Email Confirmation*/

            $conf = \DB::table('email_templates')->where('tplname', '=', 'Forgot Admin Password')->first();

            $estatus=$conf->status;
            if($estatus=='1'){
                $sysEmail = app_config('Email');
                $sysCompany = app_config('AppName');
                $fpw_link = url() . '/admin/forgot-password-token-code/'.$fprand;

                $template = $conf->message;
                $subject = $conf->subject;

                $data = array('name' => $name,
                    'business_name'=> $sysCompany,
                    'username'=> $email,
                    'ip_address'=> $ip,
                    'from'=> $sysEmail,
                    'template'=> $template,
                    'forgotpw_link' => $fpw_link
                );

                $message = _render($template, $data);
                $mail_subject = _render($subject, $data);
                $body = $message;


                /*Set Authentication*/

                $default_gt = app_config('DefaultGateway');

                if ($default_gt == 'sendmail') {
                    \Mail::send('emails.forgot-admin-password',$data,function($message) use($data,$mail_subject){
                        $message->to($data['username'])->from($data['from'])->subject($mail_subject);
                    });
                } elseif ($default_gt == 'PHPMailer') {
                    $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                    $host=$d->host_name;
                    $username=$d->username;
                    $password=$d->password;
                    $port=$d->port;
                    $secure=$d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'SendGrid') {
                    $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                    $host=$d->host_name;
                    $username=$d->username;
                    $password=$d->password;
                    $port=$d->port;
                    $secure=$d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'MailGun') {
                    $d = EmailGateway::where('name', '=', 'MailGun')->first();

                    $host=$d->host_name;
                    $username=$d->username;
                    $password=$d->password;
                    $port=$d->port;
                    $secure=$d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } else {

                }

                /*Send Message*/

                $mailer = \Swift_Mailer::newInstance($transport);
                $message = \Swift_Message::newInstance();

                $message->setSubject($mail_subject);
                $message->setFrom(array($sysEmail => $sysCompany));
                $message->setTo(array($email => $name));
                $message->setBody($body, 'text/html');
                $mailer->send($message);
            }

            return redirect('admin')->with([
                'message'=>'Your Password Already Reset. Please Check your email'
            ]);
        }else{
            return redirect('admin')->with([
                'message'=>'Sorry There is no registered user with this email address',
                'message_important'=>true
            ]);
        }

    }


    /* forgotPasswordTokenCode  Function Start Here */
    public function forgotPasswordTokenCode($token)
    {

        $appStage=app_config('AppStage');
        if($appStage=='Demo'){
            return redirect('admin')->with([
                'message'=>'This Option is Disable In Demo Mode',
                'message_important'=>true
            ]);
        }

        $tfnd=User::where('pwresetkey','=',$token)->count();

        if($tfnd=='1'){
            $d=User::where('pwresetkey','=',$token)->first();
            $name=$d->name;
            $email=$d->email;

            $rawpass=substr(str_shuffle(str_repeat('0123456789','16')),0,'16');
            $password=bcrypt($rawpass);

            $d->password=$password;
            $d->pwresetkey = '';
            $d->save();

            /*For Email Confirmation*/

            $conf = \DB::table('email_templates')->where('tplname', '=', 'Admin Password Reset')->first();

            $estatus=$conf->status;
            if($estatus=='1'){
                $sysEmail = app_config('Email');
                $sysCompany = app_config('AppName');
                $fpw_link = url().'/admin';

                $template = $conf->message;
                $subject = $conf->subject;

                $data = array('name' => $name,
                    'business_name'=> $sysCompany,
                    'username'=> $email,
                    'password'=> $rawpass,
                    'template'=>$template,
                    'sys_url' => $fpw_link
                );

                $message = _render($template, $data);
                $mail_subject = _render($subject, $data);
                $body = $message;


                /*Set Authentication*/

                $default_gt = app_config('DefaultGateway');

                if ($default_gt == 'sendmail') {
                    \Mail::send('emails.admin-password-reset',$data,function($message) use($data,$mail_subject){
                        $message->to($data['username'])->from($data['from'])->subject($mail_subject);
                    });
                } else{
                    if ($default_gt == 'PHPMailer') {
                        $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                        $host=$d->host_name;
                        $username=$d->username;
                        $password=$d->password;
                        $port=$d->port;
                        $secure=$d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'SendGrid') {
                        $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                        $host=$d->host_name;
                        $username=$d->username;
                        $password=$d->password;
                        $port=$d->port;
                        $secure=$d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'MailGun') {
                        $d = EmailGateway::where('name', '=', 'MailGun')->first();

                        $host=$d->host_name;
                        $username=$d->username;
                        $password=$d->password;
                        $port=$d->port;
                        $secure=$d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } else {

                    }


                /*Send Message*/

                $mailer = \Swift_Mailer::newInstance($transport);
                $message = \Swift_Message::newInstance();

                $message->setSubject($mail_subject);
                $message->setFrom(array($sysEmail => $sysCompany));
                $message->setTo(array($email => $name));
                $message->setBody($body, 'text/html');
                $mailer->send($message);

                /*Email Confirmation End Here*/
            }

            }
            return redirect('admin')->with([
                'message'=>'A New Password Generated. Please Check your email.'
            ]);
        }else{
            return redirect('admin')->with([
                'message'=>'Sorry Password reset Token expired or not exist, Please try again.',
                'message_important'=>true
            ]);
        }

    }




}
