<?php namespace App\Http\Controllers;

use App\Client;
use App\EmailGateway;
use App\Http\Requests;
use App\invoiceitems;
use App\invoices;
use App\tickets;
use Illuminate\Support\Facades\Input;

use Illuminate\Http\Request;

class ClientController extends Controller
{

    public function __construct()
    {
        $this->beforeFilter('csrf', array('on' => 'post'));
    }

    public function all()
    {
        $sys_menu = 'All Clients';
        $result = Client::paginate(50);
        return view('admin.all-clients', compact('result', 'sys_menu'));
    }

    public function add()
    {
        $sys_menu = 'Add New Client';
        return view('admin.client-add', compact('sys_menu'));
    }

    public function post(Request $request)
    {
        $v = \Validator::make($request->all(), [
            'fname' => 'required', 'email' => 'required', 'password' => 'required', 'address' => 'required', 'city' => 'required', 'country' => 'required', 'utype' => 'required'
        ]);

        if ($v->fails()) {
            return redirect('admin/add-new-client')->withErrors($v->errors());
        }

        $fname = Input::get('fname');
        $lname = Input::get('lname');
        $email = Input::get('email');
        $initpassword = Input::get('password');
        $password = \Hash::make($initpassword);
        $phone = Input::get('phone');
        $address = Input::get('address');
        $state = Input::get('state');
        $city = Input::get('city');
        $country = Input::get('country');
        $utype = Input::get('utype');
        $_token = Input::get('_token');


        if ($email != '') {
            $exist = \DB::table('clients')->where('email', $email)->find(1);
            if ($exist) {
                return redirect('admin/add-new-client')->with([
                    'message' => 'This Email Already Registered By A Client',
                    'message_important' => true
                ]);
            }
        }

        $client = new Client();
        $client->fname = $fname;
        $client->lname = $lname;
        $client->email = $email;
        $client->password = $password;
        $client->phone = $phone;
        $client->address = $address;
        $client->state = $state;
        $client->city = $city;
        $client->country = $country;
        $client->utype = $utype;
        $client->send_req='yes';
        $client->remember_token = $_token;
        $client->save();


        /*For Email Confirmation*/

        $conf = \DB::table('email_templates')->where('tplname', '=', 'Customer SignUp')->first();

        $estatus = $conf->status;

        if ($estatus == '1') {

            $sysEmail = app_config('Email');
            $sysCompany = app_config('AppName');
            $sysUrl = url() . '/login';

            $template = $conf->message;
            $subject = $conf->subject;

            $data = array(
                'name' => $fname . $lname,
                'business_name' => $sysCompany,
                'from' => $sysEmail,
                'username' => $email,
                'password' => $initpassword,
                'sys_url' => $sysUrl,
                'template' => $template
            );

            $message = _render($template, $data);
            $mail_subject = _render($subject, $data);
            $body = $message;

            /*Set Authentication*/

            $default_gt = app_config('DefaultGateway');

            if ($default_gt == 'sendmail') {

                \Mail::send('emails.customer-signup', $data, function ($message) use ($data, $mail_subject) {
                    $message->to($data['username'])->from($data['from'])->subject($mail_subject);
                });
            } else {
                if ($default_gt == 'PHPMailer') {
                    $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'SendGrid') {
                    $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'MailGun') {
                    $d = EmailGateway::where('name', '=', 'MailGun')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } else {

                }


                /*Send Message*/

                $mailer = \Swift_Mailer::newInstance($transport);
                $message = \Swift_Message::newInstance();

                $message->setSubject($mail_subject);
                $message->setFrom(array($sysEmail => $sysCompany));
                $message->setTo(array($email => $fname . ' ' . $lname));
                $message->setBody($body, 'text/html');
                $mailer->send($message);
            }
        }
        return redirect('admin/all-clients')->with(['message' => 'Client Add Successfully']);

    }

    public function show($id)
    {
        $sys_menu = 'Client Manage';
        $cl = Client::find($id);

        $inv = invoices::where('cid', '=', $id)->limit('10')->get();

        $st = tickets::where('userid', '=', $id)->limit('10')->get();

        return view('admin.client-view', compact('cl', 'sys_menu', 'inv', 'st'));
    }

    public function findClient(Request $request)
    {

        $this->validate($request, [
            'cid' => 'required'
        ]);

        $cid = \Input::get('cid');
        $result = Client::find($cid);
        $address = $result['address'] . "\n" . $result['state'] . "\n" . $result['city'] . "\n" . $result['country'];

        return $address;
    }

    /* searchClient  Function Start Here */
    public function searchClient(Request $request)
    {
        $v = \Validator::make($request->all(), [
            'name' => 'required'
        ]);

        if ($v->fails()) {
            return redirect('admin/all-clients')->withErrors($v->errors());
        }

        $sys_menu = 'Search Result';
        $name = Input::get('name');
        $result = Client::where('fname', 'like', "%$name%")->orWhere('lname', 'like', "%$name%")->paginate('50');

        return view('admin.all-clients', compact('result', 'sys_menu'));

    }


    /* update  Function Start Here */
    public function update(Request $request)
    {
        $cid = Input::get('cid');
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/view-client/' . $cid)->with([
                'message' => 'This Option is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $v = \Validator::make($request->all(), [
            'fname' => 'required', 'email' => 'required', 'address' => 'required', 'city' => 'required', 'country' => 'required', 'utype' => 'required'
        ]);

        if ($v->fails()) {
            return redirect('admin/view-client/' . $cid)->withErrors($v->errors());
        }

        $fname = Input::get('fname');
        $lname = Input::get('lname');
        $email = Input::get('email');
        $password = Input::get('password');
        $phone = Input::get('phone');
        $address = Input::get('address');
        $state = Input::get('state');
        $city = Input::get('city');
        $country = Input::get('country');
        $utype = Input::get('utype');

        $d = Client::find($cid);

        if ($email != '') {
            if ($email != $d->email) {
                $exit = \DB::table('clients')->where('email', $email)->first();
                if ($exit) {
                    return redirect('admin/view-client/' . $cid)->with([
                        'message' => 'This Email Already Registered By A Client',
                        'message_important' => true
                    ]);

                }
            }
        }

        if ($password != '') {
            $password = \Hash::make($password);
        } else {
            $password = $d->password;
        }

        $cl_name=$fname.' '. $lname;

        $d->fname = $fname;
        $d->lname = $lname;
        $d->email = $email;
        $d->password = $password;
        $d->phone = $phone;
        $d->address = $address;
        $d->state = $state;
        $d->city = $city;
        $d->country = $country;
        $d->utype = $utype;

        \DB::table('invoices')->where('cid','=',$cid)->update(array('cname'=>$cl_name));
        \DB::table('tickets')->where('userid','=',$cid)->update(array('name'=>$cl_name,'email'=>$email));
        \DB::table('ticketreplies')->where('userid','=',$cid)->update(array('name'=>$cl_name));

        $d->save();
        return redirect('admin/view-client/' . $cid)->with([
            'message' => 'Client Update Successfully'
        ]);

    }

    /* deleteClient  Function Start Here */
    public function deleteClient($id)
    {
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/all-clients')->with([
                'message' => 'This Option is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $d = Client::find($id);

        if ($d) {
            invoices::where('cid', '=', $id)->delete();
            invoiceitems::where('cid', '=', $id)->delete();
            tickets::where('userid', '=', $id)->delete();
            \DB::table('ticketreplies')->where('userid', '=', $id)->delete();

            $d->delete();
            return redirect('admin/all-clients')->with([
                'message' => 'Client Deleted Successfully'
            ]);
        } else {
            return redirect('admin/all-clients')->with([
                'message' => 'There Have no Client For Delete',
                'message_important' => true
            ]);
        }

    }

    /* updateImage  Function Start Here */
    public function updateImage()
    {

        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/all-clients')->with([
                'message' => 'This Option is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $destination = public_path() . '/assets/system/';


        $cmd = Input::get('cmd');
        $img = Input::file('profile_image');
        $img_name = $img->getClientOriginalName();
        $d = Client::find($cmd);

        if ($img_name != '') {
            $save_path = 'assets/system/' . $img_name;

            Input::file('profile_image')->move($destination, $img_name);
            $or_path = $save_path;
            $d->img = $or_path;
            $d->save();

            return redirect('admin/view-client/' . $cmd)->with([
                'message' => 'Update Successfully'
            ]);
        } else {
            return redirect('admin/view-client/' . $cmd)->with([
                'message' => 'Upload an Image',
                'message_important'=>true
            ]);

        }

    }


}
