<?php namespace App\Http\Controllers;

use App\Client;
use App\Http\Requests;
use App\Http\Controllers\Controller;

use App\invoices;
use App\PaymentGateways;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;

class ClientInvoiceController extends Controller {

    public function __construct()
    {
        $this->beforeFilter('csrf',array('on'=>'post'));
    }

    public function all()
    {
        $sys_menu='All Invoices';
        $cid=\Auth::client()->user()->id;
        $inv = invoices::where('cid','=',$cid)->paginate(20);
        return view('client.all-invoices', compact('inv','sys_menu'));
    }

    public function recurring()
    {
        $sys_menu='All Recurring Invoices';
        $cid=\Auth::client()->user()->id;
        $inv = invoices::where('cid','=',$cid)->where('recurring', '!=', '0')->paginate(20);
        return view('client.all-recurring-invoices', compact('inv','sys_menu'));
    }

    public function clientView($id)
    {
        $inv=invoices::find($id);
        $cl_id=$inv['cid'];
        $cl=Client::find($cl_id);
        $inv_item=\DB::table('invoiceitems')->where('invid',$id)->get();
        $tax_sum=\DB::table('invoiceitems')->where('invid',$id)->sum('tax');
        $dis_sum=\DB::table('invoiceitems')->where('invid',$id)->sum('discount');

        $pg=PaymentGateways::where('status','=','active')->get();

        return view('client.client-view',compact(array('inv','inv_item','cl','tax_sum','dis_sum','pg')));
    }

    public function printView($id){
        $inv=invoices::find($id);
        $cl_id=$inv['cid'];
        $cl=Client::find($cl_id);
        $inv_item=\DB::table('invoiceitems')->where('invid',$id)->get();
        $tax_sum=\DB::table('invoiceitems')->where('invid',$id)->sum('tax');
        $dis_sum=\DB::table('invoiceitems')->where('invid',$id)->sum('discount');

        return view('client.iprintview',compact(array('inv','inv_item','cl','tax_sum','dis_sum')));
    }

    /* payInvoice  Function Start Here */
    public function payInvoice(Request $request)
    {
        $v=\Validator::make($request->all(),[
            'payment_gateway'=>'required','cid'=>'required','inv'=>'required'
        ]);

        if($v->fails()){
            return redirect('client/all-invoices')->withErrors($v->errors());
        }

        $cid=Input::get('cid');
        $inv=Input::get('inv');
        $pg=Input::get('payment_gateway');

        $d=invoices::find($inv);
        $amount=$d->total;
        $currency_code=app_config('Currency');

        switch($pg){
            case 'paypal':
                $p=PaymentGateways::where('settings','=','paypal')->first();

                if($p){
                    $ppemail=$p->value;
                    $url = 'https://www.paypal.com/cgi-bin/webscr';

                    $params = array(
                        array('name' => "business",
                            'value' => $ppemail
                        ),
                        array('name' => "return",
                            'value' => url().'/client/invoice/ipay_submitted/'.$inv,
                        ),
                        array('name' => "cancel_return",
                            'value' => url().'/client/invoice/ipay_cancel/'.$inv,
                        ),
                        array('name' => "notify_url",
                            'value' => url().'/client/invoice/ipay_ipn/'.$inv,
                        ),
                        array('name' => "item_name_1",
                            'value' => "Payment For INV # $inv"
                        ),
                        array('name' => "amount_1",
                            'value' => $amount
                        ),
                        array('name' => "item_number_1",
                            'value' => $inv
                        ),
                        array('name' => "quantity_1",
                            'value' => '1'
                        ),
                        array('name' => "upload",
                            'value' => '1'
                        ),
                        array('name' => "cmd",
                            'value' => '_cart'
                        ),
                        array('name' => "txn_type",
                            'value' => 'cart'
                        ),
                        array('name' => "num_cart_items",
                            'value' => '1'
                        ),
                        array('name' => "rm",
                            'value' => '2'
                        ),
                        array('name' => "payment_gross",
                            'value' => $amount
                        ),
                        array('name' => "currency_code",
                            'value' => $currency_code
                        )
                    );


                    form($url, $params);


                }else{
                    return redirect('client/all-invoices')->with([
                        'message'=>'Invalid Payment Gateway',
                        'message_important'=>true
                    ]);
                }

                break;

            case 'manualpayment':
                $p=PaymentGateways::where('settings','=','manualpayment')->first();
                if($p) {
                    $mp_value = $p->value;
                    return view('client.manual-payment', compact('mp_value', 'd'));
                }else{
                        return redirect('client/all-invoices')->with([
                            'message'=>'Invalid Payment Gateway',
                            'message_important'=>true
                        ]);
                    }
                break;

            case 'stripe':
                $p=PaymentGateways::where('settings','=','stripe')->first();

                if($p){
                    $a=Client::find($cid);
                    $amount=$amount*100;
                    $mp_value = ' <script
                                        src="https://checkout.stripe.com/v2/checkout.js" class="stripe-button"
                                        data-key="'.$p->value.'"
                                        data-amount="'.$amount.'"
                                        data-name="INV #'.$d->id.'"
                                        data-email="'.$a->email.'"
                                        data-currency="'.$currency_code.'"
                                        data-description="Payment for Invoice # '.$d->id.'">
                                </script>';

                    return view('client.manual-payment', compact('mp_value', 'd'));

                }else{
                    return redirect('client/all-invoices')->with([
                        'message'=>'Invalid Payment Gateway',
                        'message_important'=>true
                    ]);
                }

                break;

            case 'authorize_net':
                $p=PaymentGateways::where('settings','=','authorize_net')->first();

                if($p){
                    $url = 'https://secure.authorize.net/gateway/transact.dll';
                    $loginID=$p->value;
                    $transactionKey=$p->extra_value;
                    $description = "Invoice Payment - $inv";
                    $invoice=$inv;
                    $sequence = rand(1, 1000);
                    $timeStamp = time();

                    $testMode = "false";
                    if (phpversion() >= '5.1.2') {
                        $fingerprint = hash_hmac("md5", $loginID . "^" . $sequence . "^" . $timeStamp . "^" . $amount . "^", $transactionKey);
                    } else {
                        $fingerprint = bin2hex(mhash(MHASH_MD5, $loginID . "^" . $sequence . "^" . $timeStamp . "^" . $amount . "^", $transactionKey));
                    }
                    $params = array(
                        array('name' => "x_login",
                            'value' => $loginID
                        ),
                        array('name' => "x_amount",
                            'value' => $amount
                        ),
                        array('name' => "x_description",
                            'value' => $description
                        ),
                        array('name' => "x_invoice_num",
                            'value' => $invoice
                        ),
                        array('name' => "x_fp_sequence",
                            'value' => $sequence
                        ),
                        array('name' => "x_fp_timestamp",
                            'value' => $timeStamp
                        ),
                        array('name' => "x_fp_hash",
                            'value' => $fingerprint
                        ),
                        array('name' => "x_test_request",
                            'value' => $testMode
                        ),
                        array('name' => "x_show_form",
                            'value' => "PAYMENT_FORM"
                        )
                    );

                   form($url, $params);

                }else{
                    return redirect('client/all-invoices')->with([
                        'message'=>'Invalid Payment Gateway',
                        'message_important'=>true
                    ]);
                }

                break;


        }

    }


    /* ipaySubmitted  Function Start Here */
    public function ipaySubmitted($id)
    {
        $d=invoices::find($id);
        $d->status="Paid";
        $d->save();

        return redirect('client/all-invoices')->with([
            'message'=>'Invoice Paid Successfully'
        ]);
    }

    /* ipayCancel  Function Start Here */
    public function ipayCancel()
    {
        return redirect('client/all-invoices')->with([
            'message'=>'Invoice Cancelled',
            'message_important'=>true
        ]);
    }

    /* ipayIpn  Function Start Here */
    public function ipayIpn()
    {
        return redirect('client/all-invoices')->with([
            'message'=>'Check Paypal Notification',
            'message_important'=>true
        ]);
    }


}
