<?php namespace App\Http\Controllers;

use App\Client;
use App\Downloads;
use App\EmailGateway;
use App\Http\Requests;
use App\invoices;
use App\tickets;
use App\Uploads;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;

class ClientPortal extends Controller
{


    public function dashboard()
    {
        if ( \Auth::client()->check() ) {
            if (\Auth::client()->user()->utype == 'normal') {
                return redirect('client/request-premium-user');
            } else {

                $sys_menu = 'Dashboard';
                $user_id = \Auth::client()->user()->id;

                $inv = invoices::where('cid', '=', $user_id)->take('10')->orderBy('id', 'desc')->get();
                $st = tickets::where('userid', '=', $user_id)->take('10')->orderBy('id', 'desc')->get();
                $uploads = Uploads::where('uid', '=', $user_id)->take('5')->orderBy('id', 'desc')->get();
                $downloads = Downloads::where('uid', '=', $user_id)->take('5')->orderBy('id', 'desc')->get();

                return view('client.dashboard', compact('inv', 'st', 'uploads', 'downloads', 'sys_menu'));
            }
        } else {
            return redirect('login');
        }

        
    }


    public function login(Request $request)
    {

        if (\Auth::client()->check()) {
            return redirect('client/dashboard');
        } else {
            return view('client.landing-page');
        }

    }


    public function index()
    {
        if (\Auth::client()->check()) {
            return $this->dashboard();
        } else {
            return redirect('login')->withErrors(['Invalid Access']);
        }
    }


    public function getLogin(Request $request)
    {

        $this->validate($request, [
            'email' => 'required', 'password' => 'required',
        ]);

        $check_input = $request->only('email', 'password');

        $public_path=public_path();
        $store_path=storage_path();

        if(is_writable($public_path)==false) {
            @chmod($public_path,755);
        }

        if(is_writable($store_path)==false){
            @chmod($store_path,755);
        }

        $remember = (Input::has('remember')) ? true : false;

        if (\Auth::client()->attempt($check_input,$remember)) {

            if (\Auth::client()->user()->utype == 'normal') {

                $request_status = \Auth::client()->user()->send_req;
                $user_email = \Auth::client()->user()->email;

                $sendRequest = ( $request_status == 'yes' ) ? false : true;

                return response()->json([
                    'validation'     => true,
                    'premiumUser'    => false,
                    'sendRequest'    => $sendRequest,
                    'url'      => url().'/client/premium-user-send-request/'.$user_email
                ]);

            } else {
                return response()->json([
                    'validation'     => true,
                    'premiumUser'    => true,
                    'url'            => url().'/client/dashboard'
                ]);
            }
        } else {
            return response()->json([
                'validation'    => false,
                'message'       => 'Please insert Valid information'
            ]);
        }
    }

    /* premiumUserRequest  Function Start Here */
    public function premiumUserRequest() {

        if ( \Auth::client()->user() ) {

            if(\Auth::client()->user()->utype=='premium'){
                return redirect('client/dashboard');
            }

            $user_email = \Auth::client()->user()->email;
            $request_status = \Auth::client()->user()->send_req;
            return view('client.landing-page', compact('user_email', 'request_status'));

        } else {
            return redirect('login');
        }
        
    }

    /* premiumUserRequestSend  Function Start Here */
    public function premiumUserRequestSend($email)
    {

        if ($email == '') {
            return redirect('login')->with([
                'message' => 'Email Can not be Empty',
                'message_important' => true
            ]);
        }


        $user = Client::where('email', '=', $email)->first();
        $fname = $user->fname;
        $lname = $user->lname;

        $user->send_req='yes';
        $user->save();

        /*For Email Confirmation*/

        $conf = \DB::table('email_templates')->where('tplname', '=', 'Send Premium User Request')->first();

        $estatus = $conf->status;
        if ($estatus == '1') {

            $sysEmail = app_config('Email');
            $sysCompany = app_config('AppName');
            $sysUrl = url() . '/active-premium-user/' . $user->id;

            $template = $conf->message;
            $subject = 'Premium User Request';

            $data = array(
                'user_name' => $fname . ' ' . $lname,
                'business_name' => $sysCompany,
                'active_link' => $sysUrl,
                'template' => $template
            );

            $message = _render($template, $data);
            $mail_subject = _render($subject, $data);
            $body = $message;


            /*Set Authentication*/

            $default_gt = app_config('DefaultGateway');

            if ($default_gt == 'sendmail') {
                \Mail::send('emails.premium-user-request', $data, function ($message) use ($mail_subject, $sysEmail, $email) {
                    $message->to($sysEmail)->from($email)->subject($mail_subject);
                });
            } else {
                if ($default_gt == 'PHPMailer') {
                    $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'SendGrid') {
                    $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'MailGun') {
                    $d = EmailGateway::where('name', '=', 'MailGun')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } else {

                }


                /*Send Message*/

                $mailer = \Swift_Mailer::newInstance($transport);


                $message = \Swift_Message::newInstance();


                $message->setSubject($mail_subject);
                $message->setFrom(array($email => $fname . ' ' . $lname));
                $message->setTo(array($sysEmail => $sysCompany));
                $message->setBody($body, 'text/html');
                $mailer->send($message);
            }
        }

        return response()->json([
            'status_code'   => '100',
            'request_send'  => 'yes',
            'message'       => 'Request Send Successfully',
        ]);
    }


    /* activePremiumUser  Function Start Here */
    public function activePremiumUser($id)
    {
        $user = Client::find($id);

        $fname = $user->fname;
        $lname = $user->lname;
        $email = $user->email;
        $user->utype = 'premium';
        $user->save();

        /*For Email Confirmation*/

        $conf = \DB::table('email_templates')->where('tplname', '=', 'Premium User Confirmation')->first();

        $estatus = $conf->status;
        if ($estatus == '1') {

            $sysEmail = app_config('Email');
            $sysCompany = app_config('AppName');
            $sysUrl = url() . '/login';

            $template = $conf->message;
            $subject = $conf->subject;

            $data = array(
                'name' => $fname . ' ' . $lname,
                'business_name' => $sysCompany,
                'sys_url' => $sysUrl,
                'template' => $template
            );

            $message = _render($template, $data);
            $mail_subject = _render($subject, $data);
            $body = $message;


            /*Set Authentication*/

            $default_gt = app_config('DefaultGateway');

            if ($default_gt == 'sendmail') {
                \Mail::send('emails.premium-user-confirm', $data, function ($message) use ($mail_subject, $sysEmail, $email) {
                    $message->to($email)->from($sysEmail)->subject($mail_subject);
                });
            } else {
                if ($default_gt == 'PHPMailer') {
                    $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'SendGrid') {
                    $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'MailGun') {
                    $d = EmailGateway::where('name', '=', 'MailGun')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } else {

                }

                /*Send Message*/

                $mailer = \Swift_Mailer::newInstance($transport);


                $message = \Swift_Message::newInstance();


                $message->setSubject($mail_subject);
                $message->setFrom(array($sysEmail => $sysCompany));
                $message->setTo(array($email => $fname . ' ' . $lname));
                $message->setBody($body, 'text/html');
                $mailer->send($message);
            }
        }
        return redirect('admin')->with([
            'message' => $fname . '  ' . $lname . ' Set As Premium User'
        ]);


    }


    public function logout(Request $request)
    {
        \Auth::client()->logout();

        if ( $request && $request->ajax() ) {
            return response()->json(['loggedOut' => true,'message' => 'Logout Successfully']);
        } else {
            return redirect('login')->with(['message' => 'Logout Successfully']);
        }

        
    }


    /* editProfile  Function Start Here */
    public function editProfile()
    {
        $cid = \Auth::client()->user()->id;

        $sys_menu = 'Edit Profile';

        $inv = invoices::where('cid', '=', $cid)->limit('10')->get();
        $st = tickets::where('userid', '=', $cid)->limit('10')->get();
        $cl = Cl_Info(\Auth::client()->user()->id);
        return view('client.edit-profile', compact('cl', 'sys_menu', 'inv', 'st'));
    }


    /* update  Function Start Here */
    public function update(Request $request)
    {
        $msg = '';
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('client/edit-profile')->with([
                'message'=>'This Option Is Disable In Demo Mode',
                'message_important'=>true
            ]);
        }

        $v = \Validator::make($request->all(), [
            'fname' => 'required', 'email' => 'required', 'address' => 'required', 'city' => 'required', 'country' => 'required'
        ]);

        $cid = Input::get('cid');
        if ($v->fails()) {
            return redirect('client/edit-profile')->withErrors($v->errors());
        }

        $fname = Input::get('fname');
        $lname = Input::get('lname');
        $email = Input::get('email');
        $password = Input::get('password');
        $phone = Input::get('phone');
        $address = Input::get('address');
        $state = Input::get('state');
        $city = Input::get('city');
        $country = Input::get('country');

        $d = Client::find($cid);
        if ($email != '') {
            if ($email != $d->email) {
                $exit = \DB::table('clients')->where('email', $email)->first();
                if ($exit) {
                    return redirect('client/edit-profile')->with([
                        'message'=>'This Email Already Registered By A Client',
                        'message_important'=>true
                    ]);
                }
            }
        }

        if ($password != '') {
            $password = \Hash::make($password);
        } else {
            $password = $d->password;
        }

        $cl_name=$fname.' '. $lname;

        if ($msg == '') {
            $d->fname = $fname;
            $d->lname = $lname;
            $d->email = $email;
            $d->password = $password;
            $d->phone = $phone;
            $d->address = $address;
            $d->state = $state;
            $d->city = $city;
            $d->country = $country;


            \DB::table('invoices')->where('cid','=',$cid)->update(array('cname'=>$cl_name));
            \DB::table('tickets')->where('userid','=',$cid)->update(array('name'=>$cl_name,'email'=>$email));
            \DB::table('ticketreplies')->where('userid','=',$cid)->update(array('name'=>$cl_name));


            $d->save();
            return redirect('client/edit-profile')->with([
                'message'=>'Profile Update Successfully'
            ]);
        } else {
            return redirect('client/edit-profile')->with([
                'message'=>'Please Update your Profile Correctly',
                'message_important'=>true
            ]);
        }
    }


    /* updateImage  Function Start Here */
    public function updateImage()
    {
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('client/edit-profile')->with([
                'message' => 'This Option is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $destination = public_path() . '/assets/system/';


        $cmd = Input::get('cmd');
        $img = Input::file('profile_image');
        $img_name = $img->getClientOriginalName();

        $d = Client::find($cmd);

        if ($img_name != '') {
            $save_path = 'assets/system/' . $img_name;

            Input::file('profile_image')->move($destination, $img_name);
            $or_path = $save_path;
            $d->img = $or_path;
            $d->save();

            return redirect('client/edit-profile')->with([
                'message' => 'Update Successfully'
            ]);
        } else {
            return redirect('client/edit-profile')->with([
                'message' => 'Upload an Image',
                'message_important'=>true
            ]);

        }

    }


    /* register  Function Start Here */
    public function register()
    {
        return view('client.landing-page');
    }

    /* postRegister  Function Start Here */
    public function postRegister(Request $request)
    {

        $v = \Validator::make($request->all(), [
            'fname' => 'required', 'email' => 'required|email', 'password' => 'required', 'country' => 'required'
        ]);

        if ($v->fails()) {
            return response()->json([
                'status_code' => '300',
                'message' => 'Please fill the inputs Correctly'
            ]);
        }

        $fname = Input::get('fname');
        $lname = Input::get('lname');
        $email = Input::get('email');
        $initpassword = Input::get('password');
        $password = \Hash::make($initpassword);
        $country = Input::get('country');
        $_token = Input::get('_token');


        if ($email != '') {
            $exist = \DB::table('clients')->where('email', $email)->find(1);
            if ($exist) {
                return response()->json([
                    'status_code' => '400',
                    'message' => 'This Email Already Registered By A Client'
                ]);
            }
        }

        $client = new Client();
        $client->fname = $fname;
        $client->lname = $lname;
        $client->email = $email;
        $client->password = $password;
        $client->phone = '';
        $client->address = '';
        $client->state = '';
        $client->city = '';
        $client->country = $country;
        $client->utype = 'normal';
        $client->send_req='no';
        $client->remember_token = $_token;
        $client->save();


        /*For Email Confirmation*/

        $conf = \DB::table('email_templates')->where('tplname', '=', 'Customer SignUp')->first();

        $estatus = $conf->status;
        if ($estatus == '1') {

            $sysEmail = app_config('Email');
            $sysCompany = app_config('AppName');
            $sysUrl = url() . '/login';

            $template = $conf->message;
            $subject = $conf->subject;

            $data = array(
                'name' => $fname . ' ' . $lname,
                'business_name' => $sysCompany,
                'username' => $email,
                'password' => $initpassword,
                'template' => $template,
                'sys_url' => $sysUrl
            );

            $message = _render($template, $data);
            $mail_subject = _render($subject, $data);
            $body = $message;


            /*Set Authentication*/

            $default_gt = app_config('DefaultGateway');

            if ($default_gt == 'sendmail') {
                \Mail::send('emails.customer-signup', $data, function ($message) use ($mail_subject, $sysEmail, $email) {
                    $message->to($email)->from($sysEmail)->subject($mail_subject);
                });
            } else {
                if ($default_gt == 'PHPMailer') {
                    $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'SendGrid') {
                    $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'MailGun') {
                    $d = EmailGateway::where('name', '=', 'MailGun')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } else {

                }


                /*Send Message*/

                $mailer = \Swift_Mailer::newInstance($transport);


                $message = \Swift_Message::newInstance();


                $message->setSubject($mail_subject);
                $message->setFrom(array($sysEmail => $sysCompany));
                $message->setTo(array($email => $fname . ' ' . $lname));
                $message->setBody($body, 'text/html');
                $mailer->send($message);
            }
        }
        return response()->json([
            'status_code'   => '100',
            'message' => 'Registration Successful'
        ]);

    }


    public function landingPage()
    {
        if ( \Auth::client()->check() ) {
            return redirect('client/dashboard');
        } else {
            $public_path=public_path();
            $store_path=storage_path();
            if(is_writable($public_path)==false) {
                @chmod($public_path,755);
            }
            if(is_writable($store_path)==false){
                @chmod($store_path,755);
            }

            return view('client.landing-page');
        }
    }


    /* forgotPassword  Function Start Here */
    public function forgotPassword()
    {
        return view('client.landing-page');
    }


    /* forgotPasswordToken  Function Start Here */
    public function forgotPasswordToken(Request $request)
    {

        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('login')->with([
                'message' => 'This Option is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $v = \Validator::make($request->all(), [
            'email' => 'required'
        ]);

        if ($v->fails()) {
            return redirect('login')->withErrors($v->errors());
        }

        $email = Input::get('email');

        $d = Client::where('email', '=', $email)->count();
        if ($d == '1') {
            $fprand = substr(str_shuffle(str_repeat('0123456789', '16')), 0, '16');
            $fptime = time() + 3600;

            $ef = Client::where('email', '=', $email)->first();
            $name = $ef->fname . ' ' . $ef->lname;

            $ef->pwresetkey = $fprand;
            $ef->pwresetexpiry = $fptime;
            $ef->save();

            $ip = \Request::getClientIp();


            /*For Email Confirmation*/

            $conf = \DB::table('email_templates')->where('tplname', '=', 'Forgot Client Password')->first();

            $estatus = $conf->status;
            if ($estatus == '1') {
                $sysEmail = app_config('Email');
                $sysCompany = app_config('AppName');
                $fpw_link = url() . '/client/forgot-password-token-code/' . $fprand;

                $template = $conf->message;
                $subject = $conf->subject;

                $data = array('name' => $name,
                    'business_name' => $sysCompany,
                    'username' => $email,
                    'ip_address' => $ip,
                    'template' => $template,
                    'forgotpw_link' => $fpw_link
                );


                $message = _render($template, $data);
                $mail_subject = _render($subject, $data);
                $body = $message;


                /*Set Authentication*/

                $default_gt = app_config('DefaultGateway');

                if ($default_gt == 'sendmail') {
                    \Mail::send('emails.forgot-client-password', $data, function ($message) use ($mail_subject, $sysEmail, $email) {
                        $message->to($email)->from($sysEmail)->subject($mail_subject);
                    });
                } else {
                    if ($default_gt == 'PHPMailer') {
                        $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'SendGrid') {
                        $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'MailGun') {
                        $d = EmailGateway::where('name', '=', 'MailGun')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } else {

                    }

                    /*Send Message*/

                    $mailer = \Swift_Mailer::newInstance($transport);
                    $message = \Swift_Message::newInstance();

                    $message->setSubject($mail_subject);
                    $message->setFrom(array($sysEmail => $sysCompany));
                    $message->setTo(array($email => $name));
                    $message->setBody($body, 'text/html');
                    $mailer->send($message);
                }
            }
            return response()->json([
                'status_code'    => '100',
                'message'   => 'Your Password Already Reset. Please Check your email'
            ]);
        } else {
            return response()->json([
                'status_code'    => '200',
                'message' => 'Sorry There is no registered user with this email address',
                'message_important' => true
            ]);
        }

    }


    /* forgotPasswordTokenCode  Function Start Here */
    public function forgotPasswordTokenCode($token)
    {

        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('login')->with([
                'message' => 'This Option is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $tfnd = Client::where('pwresetkey', '=', $token)->count();

        if ($tfnd == '1') {
            $d = Client::where('pwresetkey', '=', $token)->first();
            $name = $d->fname . ' ' . $d->lname;
            $email = $d->email;

            $rawpass = substr(str_shuffle(str_repeat('0123456789', '16')), 0, '16');
            $password = bcrypt($rawpass);

            $d->password = $password;
            $d->pwresetkey = '';
            $d->save();

            /*For Email Confirmation*/

            $conf = \DB::table('email_templates')->where('tplname', '=', 'Client Password Reset')->first();

            $estatus = $conf->status;
            if ($estatus == '1') {
                $sysEmail = app_config('Email');
                $sysCompany = app_config('AppName');
                $fpw_link = url() . '/login';

                $template = $conf->message;
                $subject = $conf->subject;

                $data = array('name' => $name,
                    'business_name' => $sysCompany,
                    'username' => $email,
                    'password' => $rawpass,
                    'template' => $template,
                    'sys_url' => $fpw_link
                );

                $message = _render($template, $data);
                $mail_subject = _render($subject, $data);
                $body = $message;


                /*Set Authentication*/

                $default_gt = app_config('DefaultGateway');

                if ($default_gt == 'sendmail') {
                    \Mail::send('emails.client-password-reset', $data, function ($message) use ($mail_subject, $sysEmail, $email) {
                        $message->to($email)->from($sysEmail)->subject($mail_subject);
                    });
                } else {
                    if ($default_gt == 'PHPMailer') {
                        $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'SendGrid') {
                        $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'MailGun') {
                        $d = EmailGateway::where('name', '=', 'MailGun')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } else {

                    }

                    /*Send Message*/

                    $mailer = \Swift_Mailer::newInstance($transport);
                    $message = \Swift_Message::newInstance();

                    $message->setSubject($mail_subject);
                    $message->setFrom(array($sysEmail => $sysCompany));
                    $message->setTo(array($email => $name));
                    $message->setBody($body, 'text/html');
                    $mailer->send($message);

                    /*Email Confirmation End Here*/
                }
            }

            return redirect('login')->with([
                'message' => 'A New Password Generated. Please Check your email.'
            ]);
        } else {
            return redirect('login')->with([
                'message' => 'Sorry Password reset Token expired or not exist, Please try again.',
                'message_important' => true
            ]);
        }

    }


}
