<?php namespace App\Http\Controllers;

use App\EmailGateway;
use App\FileInfo;
use App\Http\Requests;
use App\Uploads;
use Aws\Common\Facade\S3;
use Aws\S3\Enum\Storage;
use Aws\S3\Exception\S3Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;


class FileSharingController extends Controller
{

    public function  _construct()
    {
        $this->beforeFilter('csrf', array('on' => 'post'));
    }

    /* guestSharing  Function Start Here */
    public function dropguestSharing()
    {
        $file = \Input::file('file');
        $token_id = \Input::get('token_id');

        $time = strtotime(date('Y-m-d H:m:s'));
        $ext = $time . '-';
        $file_type = $file->getClientMimeType();

        $storage_server = app_config('StorageServer');

        if ($storage_server == 'aws') {
            $file_name = $ext . $file->getClientOriginalName();
            $file_size = $file->getSize();

            \Storage::disk('s3')->put($file_name, file_get_contents($file), 'public');

        } else {
            $destinationPath = storage_path() . '/app/';
            $file_name = $ext . $file->getClientOriginalName();
            $file_size = $file->getSize();
            $file->move($destinationPath, $file_name);
        }

        $rand = _raid('10');

        $fi = new FileInfo();
        $fi->user_id = '0';
        $fi->sname = $rand;
        $fi->file_name = $file_name;
        $fi->file_token = $token_id;
        $fi->file_size = $file_size;
        $fi->file_type = $file_type;
        $fi->save();

        return \Response::json(array(
            'tokenId' => $token_id,
            'url' => url() . '/client/remove-upload-file/' . $rand
        ));
    }


    /* guestPostSharing  Function Start Here */

    public function guestPostSharing(Request $request)
    {

        $post_size = trim(ini_get('post_max_size'));
        $post_size = substr($post_size, 0, -1);
        $post_size = ($post_size * 1024) * 1024;
        $type = \Input::get('utype');

        if ($type == 'email') {

            $v = \Validator::make($request->all(), [
                'oemail' => 'required|email', 'subject' => 'required'
            ]);

            if ($v->fails()) {
                return redirect('/')->withErrors($v->errors());
            }

            $rep_email = \Input::get('email');
            $rev_email = explode(',', $rep_email);
            $email = \Input::get('oemail');

        } else {
            $email = 'Link';
        }


        $tokenId = \Input::get('tokenId');
        $message = \Input::get('message');

        $ti = FileInfo::where('file_token', '=', $tokenId)->get();
        $file_count = $ti->count();

        $file_size = '0';
        $storage_server = app_config('StorageServer');

        if($storage_server=='aws'){
            \Storage::disk('s3')->makeDirectory($tokenId);
        }else{
            \Storage::disk('local')->makeDirectory($tokenId);
        }


        foreach ($ti as $file) {
            $file_name = $file->file_name;
            $single_file_size = $file->file_size;

            if ($storage_server == 'aws') {
                $destinationPath = $tokenId . '/' . $file_name;
                \Storage::disk('s3')->move($file_name, $destinationPath);
            } else {
                $sourcePath = storage_path() . '/app/';
                $destinationPath = storage_path() . '/app/' . $tokenId . '/';
                \File::move($sourcePath . $file_name, $destinationPath . $file_name);
            }
            $file_size += $single_file_size;
        }

        $guest_max_size = app_config('MaxUpload');

        $file_size = ($file_size / 1024) / 1024;
        $file_size = number_format($file_size, 4, '.', '');

        if ($file_size > $guest_max_size) {
            return redirect('/')->with([
                'message' => 'Files Cannot Exceed Than ' . $guest_max_size,
                'message_important' => true
            ]);

        }

        if ($file_size > $post_size) {
            return redirect('/')->with([
                'message' => 'Files Cannot Exceed' . ini_get('upload_max_filesize'),
                'message_important' => true
            ]);
        }


        $message = Input::get('message');
        $sys_exp_time = '+' . app_config('ExpireTime') . ' hours';
        $expire_time = date("Y-m-d H:m:s", strtotime($sys_exp_time));


        $d = new Uploads();
        $d->fileid = $tokenId;
        $d->uid = '0';
        $d->upload_type = $email;
        $d->upload_date = date('Y-m-d H:m:s');
        $d->filescount = $file_count;
        $d->size = $file_size;
        $d->password = 'No';
        $d->status = 'Ready';
        $d->expire = 'No';
        $d->message = $message;
        $d->password_value = '';
        $d->expire_time = $expire_time;
        $d->ip = $request->getClientIp();
        $d->save();


        if ($type == 'email') {

            $subject = \Input::get('subject');
            /*For Email Confirmation*/

            $conf = \DB::table('email_templates')->where('tplname', '=', 'File Sharing Email')->first();

            $estatus = $conf->status;
            if ($estatus == '1') {
                $sysEmail = app_config('Email');
                $sysCompany = app_config('AppName');
                $download_link = url() . '/client/file-sharing/guest-download/' . $tokenId;
                $template = $conf->message;

                $data = array(
                    'business_name' => $sysCompany,
                    'message' => $message,
                    'subject' => $subject,
                    'template' => $template,
                    'download_link' => $download_link
                );


                $message = _render($template, $data);
                $mail_subject = _render($subject, $data);
                $body = $message;


                /*Set Authentication*/

                $default_gt = app_config('DefaultGateway');

                if ($default_gt == 'sendmail') {
                    \Mail::send('emails.file-sharing', $data, function ($message) use ($mail_subject, $email, $rev_email) {
                        $message->to($rev_email)->from($email)->subject($mail_subject);
                    });
                } else {
                    if ($default_gt == 'PHPMailer') {
                        $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'SendGrid') {
                        $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'MailGun') {
                        $d = EmailGateway::where('name', '=', 'MailGun')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } else {

                    }

                    /*Send Message*/

                    $mailer = \Swift_Mailer::newInstance($transport);
                    $message = \Swift_Message::newInstance();

                    $message->setSubject($mail_subject);
                    $message->setFrom(array($email));
                    $message->setTo($rev_email);
                    $message->setBody($body, 'text/html');
                    $mailer->send($message);
                }
            }
        }

        return response()->json([
            'upload_status' => 'Data Upload and Send Successfully',
            'status_code' => '100',
            'url' => url() . '/client/file-sharing/guest-download/' . $tokenId
        ]);

    }

    /* guestDownload  Function Start Here */
    public function guestDownload($id)
    {

        $d = FileInfo::where('file_token', '=', $id)->get();

        if ($d) {
            return view('client.guest-download', compact('d', 'id'));
        } else {
            return redirect('/')->with([
                'message' => 'There Have No File For Download',
                'message_important' => true
            ]);
        }
    }

    public function removeUploadFile($id)
    {

        $d = FileInfo::where('sname', '=', $id)->first();

        $storage_server = app_config('StorageServer');
        if ($d) {
            if ($storage_server == 'aws') {
                \Storage::disk('s3')->delete($d->file_name);
            } else {
                $file_path = storage_path() . '/app/' . $d->file_name;
                \File::delete($file_path);
            }
            $d->delete();
        }

        return response()->json(['status_code' => '100']);
    }


    /* userDownload  Function Start Here */
    public function userDownload($id)
    {
        $d = FileInfo::where('file_token', '=', $id)->get();

        if ($d) {
            return view('client.user-download', compact('d', 'id'));
        } else {
            return redirect('/')->with([
                'message' => 'There Have No File For Download',
                'message_important' => true
            ]);
        }
    }


    /* userSharing  Function Start Here */
    public function userSharing()
    {
        $d = Cl_Info(\Auth::client()->user()->id);
        return view('client.file-sharing', compact('d'));
    }


    /* guestSharing  Function Start Here */
    public function userSharingPost(Request $request)
    {

        $file = \Input::file('file');
        $token_id = \Input::get('token_id');

        $time = strtotime(date('Y-m-d H:m:s'));
        $ext = $time . '-';
        $file_type = $file->getClientMimeType();

        $storage_server = app_config('StorageServer');

        if ($storage_server == 'aws') {
            $file_name = $ext . $file->getClientOriginalName();
            $file_size = $file->getSize();

            \Storage::disk('s3')->put($file_name, file_get_contents($file), 'public');

        } else {
            $destinationPath = storage_path() . '/app/';
            $file_name = $ext . $file->getClientOriginalName();
            $file_size = $file->getSize();
            $file->move($destinationPath, $file_name);
        }

        $rand = _raid('10');

        $fi = new FileInfo();
        $fi->user_id = \Auth::client()->user()->id;
        $fi->sname = $rand;
        $fi->file_name = $file_name;
        $fi->file_token = $token_id;
        $fi->file_size = $file_size;
        $fi->file_type = $file_type;
        $fi->save();

        return \Response::json(array(
            'tokenId' => $token_id,
            'url' => url() . '/client/remove-upload-file/' . $rand
        ));

    }


    /* userFilePost  Function Start Here */
    public function userFilePost(Request $request)
    {

        $post_size = trim(ini_get('post_max_size'));
        $post_size = substr($post_size, 0, -1);
        $post_size = ($post_size * 1024) * 1024;
        $type = \Input::get('utype');

        if ($type == 'email') {

            $v = \Validator::make($request->all(), [
                'oemail' => 'required|email', 'subject' => 'required'
            ]);

            if ($v->fails()) {
                return redirect('/')->withErrors($v->errors());
            }

            $rep_email = \Input::get('email');
            $rev_email = explode(',', $rep_email);
            $email = \Input::get('oemail');

        } else {
            $email = 'Link';
        }


        $tokenId = \Input::get('tokenId');
        $message = \Input::get('message');

        $ti = FileInfo::where('file_token', '=', $tokenId)->get();
        $file_count = $ti->count();

        $time = strtotime(date('Y-m-d H:m:s'));

        $file_size = '0';
        $storage_server = app_config('StorageServer');

        if($storage_server=='aws'){
            \Storage::disk('s3')->makeDirectory($tokenId);
        }else{
            \Storage::disk('local')->makeDirectory($tokenId);
        }



        $sourcePath = storage_path() . '/app/';
        $destinationPath = storage_path() . '/app/' . $tokenId . '/';

        foreach ($ti as $file) {
            $file_name = $file->file_name;
            $single_file_size = $file->file_size;

            if ($storage_server == 'aws') {
                $destinationPath = $tokenId . '/' . $file_name;
                \Storage::disk('s3')->move($file_name, $destinationPath);
            } else {
                \File::move($sourcePath . $file_name, $destinationPath . $file_name);
            }
            $file_size += $single_file_size;
        }


        $guest_max_size = app_config('ProMaxUpload');

        $file_size = ($file_size / 1024) / 1024;
        $file_size = number_format($file_size, 4, '.', '');

        if ($file_size > $guest_max_size) {
            return redirect('client/file-sharing/send-file')->with([
                'message' => 'Files Cannot Exceed Than ' . $guest_max_size,
                'message_important' => true
            ]);

        }

        if ($file_size > $post_size) {
            return redirect('client/file-sharing/send-file')->with([
                'message' => 'Files Cannot Exceed' . ini_get('upload_max_filesize'),
                'message_important' => true
            ]);
        }


        $message = Input::get('message');
        $expire_confirm = Input::get('expire_confirm');

        if ($expire_confirm == 'on') {
            $expire_time = Input::get('expire_date');
        } else {
            $sys_exp_time = '+' . app_config('ExpireTime') . ' hours';
            $expire_time = date("Y-m-d H:m:s", strtotime($sys_exp_time));
        }

        $password_conf = Input::get('password_conf');

        if ($password_conf == 'on') {
            $password = \Input::get('password');
            $password_conf = 'Yes';
            if ($password == '') {
                return redirect('client/file-sharing/send-file')->with([
                    'message' => 'Please Enter File Password',
                    'message_important' => true
                ]);
            }
        } else {
            $password_conf = 'No';
            $password = '';
        }


        $d = new Uploads();
        $d->fileid = $tokenId;
        $d->uid = \Auth::client()->user()->id;
        $d->upload_type = $email;
        $d->upload_date = date('Y-m-d H:m:s');
        $d->filescount = $file_count;
        $d->size = $file_size;
        $d->password = $password_conf;
        $d->status = 'Ready';
        $d->expire = 'No';
        $d->message = $message;
        $d->password_value = $password;
        $d->expire_time = $expire_time;
        $d->ip = $request->getClientIp();
        $d->save();
        $fid = $d->id;


        if ($type == 'email') {

            $subject = \Input::get('subject');
            /*For Email Confirmation*/

            $conf = \DB::table('email_templates')->where('tplname', '=', 'File Sharing Email')->first();

            $estatus = $conf->status;
            if ($estatus == '1') {
                $sysEmail = app_config('Email');
                $sysCompany = app_config('AppName');

                if ($password_conf == 'Yes') {
                    $download_link = url() . '/client/file-sharing/password-protected/' . $tokenId;
                } else {
                    $download_link = url() . '/client/file-sharing/user-download/' . $tokenId;
                }

                $data = array(
                    'business_name' => $sysCompany,
                    'message' => $message,
                    'subject' => $subject,
                    'download_link' => $download_link
                );

                $template = $conf->message;
                $message = _render($template, $data);
                $mail_subject = _render($subject, $data);
                $body = $message;


                /*Set Authentication*/

                $default_gt = app_config('DefaultGateway');

                if ($default_gt == 'sendmail') {
                    \Mail::send('emails.file-sharing', $data, function ($message) use ($mail_subject, $email, $rev_email) {
                        $message->to($rev_email)->from($email)->subject($mail_subject);
                    });
                } else {
                    if ($default_gt == 'PHPMailer') {
                        $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'SendGrid') {
                        $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'MailGun') {
                        $d = EmailGateway::where('name', '=', 'MailGun')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } else {

                    }

                    /*Send Message*/

                    $mailer = \Swift_Mailer::newInstance($transport);
                    $message = \Swift_Message::newInstance();

                    $message->setSubject($mail_subject);
                    $message->setFrom(array($email));
                    $message->setTo($rev_email);
                    $message->setBody($body, 'text/html');
                    $mailer->send($message);
                }
            }
        }


        if (is_numeric($fid)) {
            $d = Uploads::find($fid);
            $password_status = $d->password;
            if ($password_status == 'Yes') {

                return response()->json([
                    'upload_status' => 'File Upload Successfully. Please Password For download the File',
                    'status_code' => '100',
                    'url' => url() . '/client/file-sharing/password-protected/' . $tokenId
                ]);

            } else {

                return response()->json([
                    'upload_status' => 'File Upload Successfully.',
                    'status_code' => '100',
                    'url' => url() . '/client/file-sharing/user-download/' . $tokenId
                ]);
            }
        }

    }


    /* passwordProtected  Function Start Here */
    public function passwordProtected($id)
    {
        $d = Uploads::where('fileid', '=', $id)->first();

        return view('client.password-protected', compact('d'));
    }

    /* downloadPasswordProtectedFile  Function Start Here */
    public function downloadPasswordProtectedFile(Request $request)
    {
        $v = \Validator::make($request->all(), [
            'password' => 'required'
        ]);

        $cmd = \Input::get('cmd');

        if ($v->fails()) {
            return redirect('client/file-sharing/password-protected/' . $cmd)->withErrors($v->errors());
        }

        $d = Uploads::where('fileid', '=', $cmd)->first();
        $password_value = $d->password_value;
        $password = \Input::get('password');
        $uid = $d->uid;

        if ($password !== $password_value) {
            return redirect('client/file-sharing/password-protected/' . $cmd)->with([
                'message' => 'Password Does not match',
                'message_important' => true
            ]);
        } else {
            return redirect('client/file-sharing/user-download/' . $cmd);
        }

    }


    /* allClientUploads  Function Start Here */
    public function allClientUploads()
    {
        $sys_menu = 'All Uploads';
        $uid = \Auth::client()->user()->id;
        $u = Uploads::where('uid', '=', $uid)->paginate(20);
        return view('client.uploads', compact('u', 'sys_menu'));
    }

    /* guestDownloadImageFile  Function Start Here */
    public function guestDownloadImageFile($id, $name)
    {
        $store_type = app_config('StorageServer');
        clearstatcache(\Request::url());
        $d = FileInfo::where('file_token', '=', $id)->where('file_name', '=', $name)->first();
        if ($d) {

            if ($store_type == 'aws') {
                $directory = $id . '/' . $name;
                $bucket = app_config('AWSBucket');
//                $file_path='https://s3-eu-west-1.amazonaws.com/'.$bucket.'/'.$directory;

                $s3 = \Storage::disk('s3');
                $file_path = $s3->getDriver()->getAdapter()->getClient()->getObjectUrl($bucket, $directory);
                echo "<img src='$file_path'/>";

            } else {
                $file_path = storage_path() . '/app/' . $id . "/" . $name;
                $finfo = finfo_open(FILEINFO_MIME_TYPE);
                $mime = finfo_file($finfo, $file_path);
                $length = filesize($file_path);

                header("content-type: $mime");
                header("content-length: $length");

                readfile($file_path);
                exit;

            }
        }
    }


    /* userDownloadImageFile  Function Start Here */
    public function userDownloadImageFile($id, $name)
    {
        $store_type = app_config('StorageServer');
        clearstatcache(\Request::url());
        $d = FileInfo::where('file_token', '=', $id)->where('file_name', '=', $name)->first();
        if ($d) {
            if ($store_type == 'aws') {
                $directory = $id . '/' . $name;
                $bucket = app_config('AWSBucket');
//                $file_path='https://s3-eu-west-1.amazonaws.com/'.$bucket.'/'.$directory;

                $s3 = \Storage::disk('s3');
                $file_path = $s3->getDriver()->getAdapter()->getClient()->getObjectUrl($bucket, $directory);
                echo "<img src='$file_path'/>";

            } else {
                $file_path = storage_path() . '/app/' . $id . "/" . $name;
                $finfo = finfo_open(FILEINFO_MIME_TYPE);
                $mime = finfo_file($finfo, $file_path);
                $length = filesize($file_path);

                header("content-type: $mime");
                header("content-length: $length");

                readfile($file_path);
                exit;
            }
        }
    }


    /* downloadFile  Function Start Here */
    public function guestDownloadFile($id, $name)
    {
        $store_type = app_config('StorageServer');
        clearstatcache(\Request::url());
        $d = FileInfo::where('file_token', '=', $id)->where('file_name', '=', $name)->first();

        if ($d) {
            if ($store_type == 'aws') {
                $directory = $id . '/' . $name;
                $disk = \Storage::disk('s3')->get($directory);
                header("Content-type: $d->file_type");
                header("Content-Disposition: attachment; filename=$name");
                echo $disk;
            } else {
                $file_path = storage_path() . '/app/' . $id . "/" . $name;
                return \Response::download($file_path, $name);
            }


        } else {
            return redirect('/')->with([
                'message' => 'There have no file For Download',
                'message_important' => true
            ]);
        }

    }

    /* downloadFile  Function Start Here */
    public function userDownloadFile($id, $name)
    {
        $store_type = app_config('StorageServer');
        clearstatcache(\Request::url());
        $d = FileInfo::where('file_token', '=', $id)->where('file_name', '=', $name)->first();
        $fileid = $d->sname;

        if ($d) {
            if ($store_type == 'aws') {
                $directory = $id . '/' . $name;
                $disk = \Storage::disk('s3')->get($directory);
                header("Content-type: $d->file_type");
                header("Content-Disposition: attachment; filename=$name");
                echo $disk;
            } else {
                $file_path = storage_path() . '/app/' . $id . "/" . $name;
                return \Response::download($file_path, $name);
            }


        } else {
            return redirect('/')->with([
                'message' => 'There have no file For Download',
                'message_important' => true
            ]);
        }

    }

    /* guestBatchDownload  Function Start Here */
    public function guestBatchDownload()
    {
        $file_token = \Input::get('token_id');

        $store_type = app_config('StorageServer');
        if($store_type=='aws'){
            return redirect('client/file-sharing/guest-download/'.$file_token)->with([
                'message'=>'Batch Download Is not available For Amazon S3. In future update you will find this'
            ]);
        }

        $file_id = \Input::get('file_id');
        $time = strtotime(date('Y-m-d H:m:s'));

        \Storage::disk('local')->makeDirectory($time);

        $sourcePath = storage_path() . '/app/' . $file_token . '/';
        $destinationPath = storage_path() . '/app/' . $time . '/';

        foreach ($file_id as $fid) {
            if ($fid !== '') {
                $d = FileInfo::where('sname', '=', $fid)->first();
                $file_name = $d->file_name;
                \File::copy($sourcePath . $file_name, $destinationPath . $file_name);
            }
        }

        $destinationPath = storage_path() . '/app/' . $time . '/';
        $rootPath = realpath($destinationPath);
        $zip_file = storage_path() . '/app/' . $file_token . '.zip';
        $zip = new \ZipArchive();

        $zip->open($zip_file, \ZipArchive::CREATE | \ZipArchive::OVERWRITE);
        $files = new \RecursiveIteratorIterator(
            new \RecursiveDirectoryIterator($rootPath),
            \RecursiveIteratorIterator::LEAVES_ONLY
        );

        foreach ($files as $name => $file) {
            if (!$file->isDir()) {
                $filePath = $file->getRealPath();
                $relativePath = substr($filePath, strlen($rootPath) + 1);
                $zip->addFile($filePath, $relativePath);
            }
        }

        $zip->close();

        \Storage::disk('local')->deleteDirectory($time);

        return response()->download($zip_file)->deleteFileAfterSend(true);

    }

    /* userBatchDownload  Function Start Here */
    public function userBatchDownload()
    {
        $file_id = \Input::get('file_id');
        $file_token = \Input::get('token_id');

        $store_type = app_config('StorageServer');
        if($store_type=='aws'){
            return redirect('client/file-sharing/guest-download/'.$file_token)->with([
                'message'=>'Batch Download Is not available For Amazon S3.In Future update you will find this'
            ]);
        }


        $time = strtotime(date('Y-m-d H:m:s'));

        \Storage::disk('local')->makeDirectory($time);

        $sourcePath = storage_path() . '/app/' . $file_token . '/';
        $destinationPath = storage_path() . '/app/' . $time . '/';

        foreach ($file_id as $fid) {
            if ($fid !== '') {
                $d = FileInfo::where('sname', '=', $fid)->first();
                $file_name = $d->file_name;
                \File::copy($sourcePath . $file_name, $destinationPath . $file_name);
            }
        }

        $destinationPath = storage_path() . '/app/' . $time . '/';
        $rootPath = realpath($destinationPath);
        $zip_file = storage_path() . '/app/' . $file_token . '.zip';
        $zip = new \ZipArchive();

        $zip->open($zip_file, \ZipArchive::CREATE | \ZipArchive::OVERWRITE);
        $files = new \RecursiveIteratorIterator(
            new \RecursiveDirectoryIterator($rootPath),
            \RecursiveIteratorIterator::LEAVES_ONLY
        );

        foreach ($files as $name => $file) {
            if (!$file->isDir()) {
                $filePath = $file->getRealPath();
                $relativePath = substr($filePath, strlen($rootPath) + 1);
                $zip->addFile($filePath, $relativePath);
            }
        }

        $zip->close();

        \Storage::disk('local')->deleteDirectory($time);

        return response()->download($zip_file)->deleteFileAfterSend(true);

    }


    /* deleteFile  Function Start Here */
    public function deleteFile($id)
    {

        $appStage = app_config('AppStage');
        $store_type = app_config('StorageServer');
        if ($appStage == 'Demo') {
            return redirect('client/uploads')->with([
                'message' => 'This Option is Disable In Demo Mode',
                'message_important' => true
            ]);
        }


        $d = Uploads::where('fileid', '=', $id)->where('uid', '=', \Auth::client()->user()->id)->first();

        if ($d) {
            if ($d->status == 'Ready') {
                if ($store_type == 'aws') {
                    \Storage::disk('s3')->deleteDirectory($id);
                } else {
                    \Storage::disk('local')->deleteDirectory($id);
                }
            }

            $d->delete();

            return redirect('client/uploads')->with([
                'message' => 'File Deleted Successfully'
            ]);
        } else {
            return redirect('client/uploads')->with([
                'message' => 'There Have no File For Delete',
                'message_important' => true
            ]);
        }
    }

    /* destroyFile  Function Start Here */
    public function destroyFile($id)
    {
        $store_type = app_config('StorageServer');

        $d = Uploads::where('fileid', '=', $id)->where('uid', '=', \Auth::client()->user()->id)->first();

        if ($d) {
            if ($d->status == 'Ready') {
                if ($store_type == 'aws') {
                    \Storage::disk('s3')->deleteDirectory($id);
                } else {
                    \Storage::disk('local')->deleteDirectory($id);
                }
            }

            $d->status = 'Removed';
            $d->expire = 'Yes';
            $d->save();
            return redirect('client/uploads')->with([
                'message' => 'File Destroyed Successfully'
            ]);
        } else {
            return redirect('client/uploads')->with([
                'message' => 'There Have no File For Destroy',
                'message_important' => true
            ]);
        }
    }


    /* userShareFile  Function Start Here */

    public function userShareFile($id)
    {

        $url = url() . '/client/file-sharing/user-download/' . $id;
        $token = csrf_token();

        echo '
<div class="modal-header">
	<button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
	<h3>Share Your File</h3>
</div>
<div class="modal-body">

<form role="form" id="form_status_update" method="post">
<input type="hidden" name="_token" value="' . $token . '">

  <div class="form-group">
    <label for="cid">Link To Folder</label>
       <input type="text" value="' . $url . '" class="form-control" id="shareFolder">
  </div>

<hr>
      <div class="form-group">
           <label for="subject">Send This Link TO</label>
            <input type="email" class="form-control" id="email" name="email" placeholder="Email"><br>
          <textarea class="form-control" rows="5" name="message" placeholder="Message" id="message"></textarea>
      </div>

</form>

</div>
<div class="modal-footer">

	<input type="hidden" id="cmd" name="cmd" value=' . $id . '>
	<button id="share_file" class="btn btn-primary">Share</button>
	<button type="button" data-dismiss="modal" class="btn">Close</button>
</div>';
    }

    /* userShareFilePost  Function Start Here */

    public function userShareFilePost()
    {

        $cmd = \Input::get('cmd');
        $email = \Input::get('email');
        $message = \Input::get('message');

        $d = Uploads::where('fileid', '=', $cmd)->first();

        if ($d) {
            $password_conf = $d->password;
            $subject = "File From " . app_config('AppName');
            /*For Email Confirmation*/

            $conf = \DB::table('email_templates')->where('tplname', '=', 'File Sharing Email')->first();

            $estatus = $conf->status;
            if ($estatus == '1') {
                $sysEmail = \Auth::client()->user()->email;
                $sysCompany = \Auth::client()->user()->fname . ' ' . \Auth::client()->user()->lname;

                if ($password_conf == 'Yes') {
                    $download_link = url() . '/client/file-sharing/password-protected/' . $cmd;
                } else {
                    $download_link = url() . '/client/file-sharing/user-download/' . $cmd;
                }

                $data = array(
                    'business_name' => $sysCompany,
                    'message' => $message,
                    'subject' => $subject,
                    'download_link' => $download_link
                );

                $template = $conf->message;
                $message = _render($template, $data);
                $mail_subject = _render($subject, $data);
                $body = $message;


                /*Set Authentication*/

                $default_gt = app_config('DefaultGateway');

                if ($default_gt == 'sendmail') {
                    \Mail::send('emails.file-sharing', $data, function ($message) use ($mail_subject, $sysEmail, $email) {
                        $message->to($email)->from($sysEmail)->subject($mail_subject);
                    });
                } else {
                    if ($default_gt == 'PHPMailer') {
                        $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'SendGrid') {
                        $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } elseif ($default_gt == 'MailGun') {
                        $d = EmailGateway::where('name', '=', 'MailGun')->first();

                        $host = $d->host_name;
                        $username = $d->username;
                        $password = $d->password;
                        $port = $d->port;
                        $secure = $d->secure;

                        $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                        $transport->setUsername($username);
                        $transport->setPassword($password);

                    } else {

                    }

                    /*Send Message*/

                    $mailer = \Swift_Mailer::newInstance($transport);
                    $message = \Swift_Message::newInstance();

                    $message->setSubject($mail_subject);
                    $message->setFrom($sysEmail);
                    $message->setTo($email);
                    $message->setBody($body, 'text/html');
                    $mailer->send($message);
                }
            }
        } else {
            return 'File Not Found For Share';
        }

        return '1';

    }


}
