<?php namespace App\Http\Controllers;

use App\Client;
use App\Http\Requests;
use App\invoiceitems;
use App\invoices;
use Illuminate\Http\Request;
use App\EmailGateway;


class InvoiceController extends Controller
{

    public function __construct()
    {
        $this->beforeFilter('csrf', array('on' => 'post'));
    }

    public function all()
    {
        $sys_menu = 'All Invoices';
        $inv = invoices::paginate(20);
        return view('admin.all-invoices', compact('inv', 'sys_menu'));
    }

    public function recurring()
    {
        $sys_menu = 'All Recurring Invoices';
        $inv = invoices::where('recurring', '!=', '0')->paginate(20);
        return view('admin.all-recurring-invoices', compact('inv', 'sys_menu'));
    }

    public function addInvoice()
    {
        $sys_menu = 'Create New Invoice';
        $cl = Client::all();
        $r = 'normal';
        return view('admin.add-new-invoice', compact('cl', 'r', 'sys_menu'));
    }


    public function postInvoice(Request $request)
    {
        $v = \Validator::make($request->all(), [
            'cid' => 'required', 'idate' => 'required', 'ddate' => 'required'
        ]);

        if ($v->fails()) {
            return redirect('admin/add-new-invoice')->withErrors($v->errors());
        }

        $cid = \Input::get('cid');
        $notes = \Input::get('notes');
        $amount = \Input::get('amount');
        $idate = \Input::get('idate');
        $ddate = \Input::get('ddate');
        $pdate = \Input::get('pdate');

        if ($cid == '') {
            return redirect('admin/add-new-invoice')->with(array(
                'message' => 'Select a Customer',
                'message_important' => true
            ));
        }

        if ($idate == '') {
            return redirect('admin/add-new-invoice')->with(array(
                'message' => 'Invoice Created date is required',
                'message_important' => true
            ));
        }

        if ($ddate == '') {
            return redirect('admin/add-new-invoice')->with(array(
                'message' => 'Invoice Due date is required',
                'message_important' => true
            ));
        }
        if ($pdate == '') {
            return redirect('admin/add-new-invoice')->with(array(
                'message' => 'Invoice Paid date is required',
                'message_important' => true
            ));
        }

        if ($amount == '') {
            return redirect('admin/add-new-invoice')->with(array(
                'message' => 'At least one item is required',
                'message_important' => true
            ));
        }

        $qty = \Input::get('qty');
        $sTotal = '0';
        $i = '0';
        foreach ($amount as $samount) {
            $amount[$i] = $samount;
            $sTotal += $samount * ($qty[$i]);
            $i++;
        }

        $ltotal = \Input::get('ltotal');
        $pTotal = '0';
        $x = '0';
        foreach ($ltotal as $lt) {
            $ltotal[$x] = $lt;
            $pTotal += $lt;
            $x++;
        }

        $repeat = \Input::get('repeat');
        $its = strtotime($idate);
        $nd = $pdate;
        if ($repeat == '0') {
            $r = '0';
        } elseif ($repeat == 'week1') {
            $r = '+1 week';
            $nd = date('Y-m-d', strtotime('+1 week', $its));
        } elseif ($repeat == 'weeks2') {
            $r = '+2 weeks';
            $nd = date('Y-m-d', strtotime('+2 weeks', $its));
        } elseif ($repeat == 'month1') {
            $r = '+1 month';
            $nd = date('Y-m-d', strtotime('+1 month', $its));
        } elseif ($repeat == 'months2') {
            $r = '+2 months';
            $nd = date('Y-m-d', strtotime('+2 months', $its));
        } elseif ($repeat == 'months3') {
            $r = '+3 months';
            $nd = date('Y-m-d', strtotime('+3 months', $its));
        } elseif ($repeat == 'months6') {
            $r = '+6 months';
            $nd = date('Y-m-d', strtotime('+6 months', $its));
        } elseif ($repeat == 'year1') {
            $r = '+1 year';
            $nd = date('Y-m-d', strtotime('+1 year', $its));
        } elseif ($repeat == 'years2') {
            $r = '+2 years';
            $nd = date('Y-m-d', strtotime('+2 years', $its));
        } elseif ($repeat == 'years3') {
            $r = '+3 years';
            $nd = date('Y-m-d', strtotime('+3 years', $its));
        } else {
            return redirect('admin/add-new-invoice')->with(array(
                'message' => 'Date Parsing Error',
                'message_important' => true
            ));
        }


        $cl = Client::find($cid);
        $cl_name = $cl['fname'] . ' ' . $cl['lname'];
        $cl_email = $cl->email;

        $inv = new invoices();
        $inv->cid = $cid;
        $inv->cname = $cl_name;
        $inv->created = $idate;
        $inv->duedate = $ddate;
        $inv->datepaid = $nd;
        $inv->subtotal = $sTotal;
        $inv->total = $pTotal;
        $inv->status = 'Unpaid';
        $inv->pmethod = '';
        $inv->recurring = $r;
        $inv->note = $notes;
        $inv->save();
        $inv_id = $inv->id;

        $tax = \Input::get('taxed');
        $discount = \Input::get('discount');
        $description = \Input::get('desc');

        $i = '0';
        foreach ($description as $item) {
            $ltotal = ($amount[$i]) * ($qty[$i]);
            $ttotal = ($ltotal * $tax[$i]) / 100;
            $dtotal = ($ltotal * $discount[$i]) / 100;

            $fTotal = $ltotal + $ttotal - $dtotal;

            $d = new invoiceitems();
            $d->invid = $inv_id;
            $d->cid = $cid;
            $d->item = $item;
            $d->qty = $qty[$i];
            $d->price = $amount[$i];
            $d->tax = $ttotal;
            $d->discount = $dtotal;
            $d->subtotal = $ltotal;
            $d->total = $fTotal;
            $d->save();
            $i++;
        }

        /*For Email Confirmation*/

        $conf = \DB::table('email_templates')->where('tplname', '=', 'Customer Invoice Created')->first();


        $estatus = $conf->status;
        if ($estatus == '1') {

            $sysEmail = app_config('Email');
            $sysCompany = app_config('AppName');
            $sysUrl = url() . '/login';

            $template = $conf->message;
            $subject = $conf->subject;

            $data = array('name' => $cl_name,
                'business_name' => $sysCompany,
                'invoice_id' => $inv_id,
                'invoice_amount' => $pTotal,
                'template' => $template,
                'sys_url' => $sysUrl
            );

            $message = _render($template, $data);
            $mail_subject = _render($subject, $data);
            $body = $message;


            /*Set Authentication*/

            $default_gt = app_config('DefaultGateway');

            if ($default_gt == 'sendmail') {
                \Mail::send('emails.invoice-created', $data, function ($message) use ($mail_subject, $sysEmail, $cl_email) {
                    $message->to($cl_email)->from($sysEmail)->subject($mail_subject);
                });

            } else {
                if ($default_gt == 'PHPMailer') {
                    $d = EmailGateway::where('name', '=', 'PHPMailer')->first();
                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'SendGrid') {
                    $d = EmailGateway::where('name', '=', 'SendGrid')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } elseif ($default_gt == 'MailGun') {
                    $d = EmailGateway::where('name', '=', 'MailGun')->first();

                    $host = $d->host_name;
                    $username = $d->username;
                    $password = $d->password;
                    $port = $d->port;
                    $secure = $d->secure;

                    $transport = \Swift_SmtpTransport::newInstance($host, $port, $secure);
                    $transport->setUsername($username);
                    $transport->setPassword($password);

                } else {

                }


                /*Send Message*/

                $mailer = \Swift_Mailer::newInstance($transport);
                $message = \Swift_Message::newInstance();

                $message->setSubject($mail_subject);
                $message->setFrom(array($sysEmail => $sysCompany));
                $message->setTo(array($cl_email => $cl_name));
                $message->setBody($body, 'text/html');
                $mailer->send($message);


                /*Email Confirmation End Here*/

            }
        }

        return redirect('admin/view-invoice/' . $inv_id)->with([
            'message' => 'Invoice Created Successfully'
        ]);

    }

    public function show($id)
    {
        $sys_menu = 'Invoice Manage';
        $inv = invoices::find($id);
        $cl_id = $inv['cid'];
        $cl = Client::find($cl_id);
        $inv_item = \DB::table('invoiceitems')->where('invid', $id)->get();
        $tax_sum = \DB::table('invoiceitems')->sum('tax');
        $dis_sum = \DB::table('invoiceitems')->sum('discount');


        return view('admin.invoice-view', compact(array('inv', 'inv_item', 'cl', 'tax_sum', 'dis_sum', 'sys_menu')));
    }


    public function addRecurring()
    {
        $sys_menu = 'Add New Invoice';
        $cl = Client::all();
        $r = 'recurring';
        return view('admin.add-new-invoice', compact('cl', 'r', 'sys_menu'));
    }

    public function paidInvoice(Request $request)
    {
        $this->validate($request, [
            'iid' => 'required'
        ]);

        $iid = \Input::get('iid');
        $d = invoices::find($iid);
        $d->status = 'Paid';
        $d->save();

        \Session::flash('message', 'Invoice Marked as Paid');

        return redirect('admin/view-invoice/' . $iid);
    }

    public function unpaidInvoice(Request $request)
    {
        $this->validate($request, [
            'iid' => 'required'
        ]);

        $iid = \Input::get('iid');
        $d = invoices::find($iid);
        $d->status = 'Unpaid';
        $d->save();

        \Session::flash('message', 'Invoice Marked as Unpaid');

        return redirect('admin/view-invoice/' . $iid);
    }

    public function cancelledInvoice(Request $request)
    {
        $this->validate($request, [
            'iid' => 'required'
        ]);

        $iid = \Input::get('iid');
        $d = invoices::find($iid);
        $d->status = 'Cancelled';
        $d->save();

        \Session::flash('message', 'Invoice Marked as Cancelled');

        return redirect('admin/view-invoice/' . $iid);
    }


    public function partiallyPaidInvoice(Request $request)
    {
        $this->validate($request, [
            'iid' => 'required'
        ]);

        $iid = \Input::get('iid');
        $d = invoices::find($iid);
        $d->status = 'Partially Paid';
        $d->save();

        \Session::flash('message', 'Invoice Marked as Partially Paid');

        return redirect('admin/view-invoice/' . $iid);
    }

    /* clientIView  Function Start Here */

    public function clientIView($id)
    {
        $inv = invoices::find($id);
        $cl_id = $inv['cid'];
        $cl = Client::find($cl_id);
        $inv_item = \DB::table('invoiceitems')->where('invid', $id)->get();
        $tax_sum = \DB::table('invoiceitems')->sum('tax');
        $dis_sum = \DB::table('invoiceitems')->sum('discount');

        return view('admin.client-iview', compact(array('inv', 'inv_item', 'cl', 'tax_sum', 'dis_sum')));
    }


    public function printView($id)
    {
        $inv = invoices::find($id);
        $cl_id = $inv['cid'];
        $cl = Client::find($cl_id);
        $inv_item = \DB::table('invoiceitems')->where('invid', $id)->get();
        $tax_sum = \DB::table('invoiceitems')->sum('tax');
        $dis_sum = \DB::table('invoiceitems')->sum('discount');

        return view('admin.iprintview', compact(array('inv', 'inv_item', 'cl', 'tax_sum', 'dis_sum')));
    }

    /* editInvoice  Function Start Here */

    public function editInvoice($id)
    {
        $sys_menu = 'Edit Invoice';
        $inv = invoices::find($id);
        $cl_id = $inv['cid'];
        $cl = Client::find($cl_id);
        $address = $cl['address'] . "\n" . $cl['state'] . "\n" . $cl['city'] . "\n" . $cl['country'];

        $inv_item = \DB::table('invoiceitems')->where('invid', $id)->get();
        $tax_sum = \DB::table('invoiceitems')->sum('tax');
        $dis_sum = \DB::table('invoiceitems')->sum('discount');

        return view('admin.invoice-edit', compact('inv', 'inv_item', 'cl', 'tax_sum', 'dis_sum', 'address', 'sys_menu'));
    }

    /* updateInvoice  Function Start Here */
    public function updateInvoice($id)
    {
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/invoice-edit/' . $id)->with([
                'message' => 'This Option is disable in Demo mode',
                'message_important' => true
            ]);
        }

        $d = invoices::find($id);

        $repeat = \Input::get('repeat');

        $idate = \Input::get('idate');
        $ddate = \Input::get('ddate');
        $pdate = \Input::get('pdate');
        $amount = \Input::get('amount');

        $qty = \Input::get('qty');
        $sTotal = '0';
        $i = '0';
        foreach ($amount as $samount) {
            $amount[$i] = $samount;
            $sTotal += $samount * ($qty[$i]);
            $i++;
        }

        $ltotal = \Input::get('ltotal');
        $pTotal = '0';
        $x = '0';
        foreach ($ltotal as $lt) {
            $ltotal[$x] = $lt;
            $pTotal += $lt;
            $x++;
        }


        $its = strtotime($idate);
        $nd = $pdate;

        if ($repeat == '0') {
            $r = '0';
        } elseif ($repeat == 'week1') {
            $r = '+1 week';
            $nd = date('Y-m-d', strtotime('+1 week', $its));
        } elseif ($repeat == 'weeks2') {
            $r = '+2 weeks';
            $nd = date('Y-m-d', strtotime('+2 weeks', $its));
        } elseif ($repeat == 'month1') {
            $r = '+1 month';
            $nd = date('Y-m-d', strtotime('+1 month', $its));
        } elseif ($repeat == 'months2') {
            $r = '+2 months';
            $nd = date('Y-m-d', strtotime('+2 months', $its));
        } elseif ($repeat == 'months3') {
            $r = '+3 months';
            $nd = date('Y-m-d', strtotime('+3 months', $its));
        } elseif ($repeat == 'months6') {
            $r = '+6 months';
            $nd = date('Y-m-d', strtotime('+6 months', $its));
        } elseif ($repeat == 'year1') {
            $r = '+1 year';
            $nd = date('Y-m-d', strtotime('+1 year', $its));
        } elseif ($repeat == 'years2') {
            $r = '+2 years';
            $nd = date('Y-m-d', strtotime('+2 years', $its));
        } elseif ($repeat == 'years3') {
            $r = '+3 years';
            $nd = date('Y-m-d', strtotime('+3 years', $its));
        } else {
            return redirect('admin/invoice-edit/' . $id)->with([
                'message' => 'Date Parsing Error',
                'message_true' => true
            ]);
        }

        $notes = \Input::get('notes');

        if ($d) {
            $d->created = $idate;
            $d->duedate = $ddate;
            $d->subtotal = $sTotal;
            $d->total = $pTotal;
            $d->datepaid = $nd;
            $d->recurring = $r;
            $d->note = $notes;
            $d->save();
        } else {
            return redirect('admin/invoice-edit/'.$id)->with([
                'message'=>'There have no Invoice for Edit',
                'message_true'=>true
            ]);
        }


        $tax = \Input::get('taxed');
        $discount = \Input::get('discount');
        $description = \Input::get('desc');

        \DB::table('invoiceitems')->where('invid', '=', $id)->delete();

        $i = '0';
        foreach ($description as $item) {
            $ltotal = ($amount[$i]) * ($qty[$i]);
            $ttotal = ($ltotal * $tax[$i]) / 100;
            $dtotal = ($ltotal * $discount[$i]) / 100;

            $fTotal = $ltotal + $ttotal - $dtotal;

            $d = new invoiceitems();
            $d->invid = $id;
            $d->item = $item;
            $d->qty = $qty[$i];
            $d->price = $amount[$i];
            $d->tax = $ttotal;
            $d->discount = $dtotal;
            $d->subtotal = $ltotal;
            $d->total = $fTotal;
            $d->save();
            $i++;
        }

        return redirect('admin/invoice-edit/'.$id)->with([
            'message'=>'Invoice Updated Successfully'
        ]);

    }

    /* deleteInvoice  Function Start Here */
    public function deleteInvoice($id)
    {
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/all-invoices')->with([
                'message' => 'This Option Is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $d = invoices::find($id);

        if ($d) {

            \DB::table('invoiceitems')->where('invid', '=', $id)->delete();

            $d->delete();

            return redirect('admin/all-invoices')->with([
                'message' => 'Invoice Deleted Successfully'
            ]);
        } else {
            return redirect('admin/all-invoices')->with([
                'message' => 'There Have no Invoice For Delete',
                'message_important' => true
            ]);
        }
    }

    /* stopRecurringInvoice  Function Start Here */
    public function stopRecurringInvoice($id)
    {
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/all-recurring-invoices')->with([
                'message' => 'This Option Is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $d = invoices::find($id);

        if ($d) {
            $d->recurring = '0';
            $d->save();

            return redirect('admin/all-recurring-invoices')->with([
                'message' => 'Stop Recurring Invoice Successfully'
            ]);
        } else {
            return redirect('admin/all-recurring-invoices')->with([
                'message' => 'There Have no Invoice For Delete',
                'message_important' => true
            ]);
        }
    }


}
