<?php namespace App\Http\Controllers;

use App\appconfig;
use App\EmailGateway;
use App\Http\Requests;
use App\Http\Controllers\Controller;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;


class SystemSettingController extends Controller
{

    public function __construct()
    {
        $this->beforeFilter('csrf', array('on' => 'post'));
    }

    public function index()
    {
        $sys_menu = 'System Settings';
        $eg = EmailGateway::all();
        $storage_server = app_config('StorageServer');
        return view('admin.SystemSetting', compact('eg', 'sys_menu', 'storage_server'));
    }

    public function localization()
    {
        $sys_menu = 'Localization';
        return view('admin.localization', compact('sys_menu'));
    }

    /* localizationPost  Function Start Here */
    public function localizationPost(Request $request)
    {
        $v = \Validator::make($request->all(), [
            'country' => 'required', 'currency_name' => 'required', 'currency_code' => 'required'
        ]);

        if ($v->fails()) {
            return redirect('admin/localization')->withErrors($v->errors());
        }

        $country = \Input::get('country');
        $currency_name = \Input::get('currency_name');
        $currency_code = \Input::get('currency_code');

        if ($country != '') {
            appconfig::where('setting', '=', 'Country')->update(['value' => $country]);
        }

        if ($currency_name != '') {
            appconfig::where('setting', '=', 'Currency')->update(['value' => $currency_name]);
        }

        if ($currency_code != '') {
            appconfig::where('setting', '=', 'CurrencyCode')->update(['value' => $currency_code]);
        }

        return redirect('admin/localization')->with([
            'message' => 'Localization Update Successfully'
        ]);

    }


    /* paymentGateway  Function Start Here */
    public function paymentGateway()
    {
        $sys_menu = 'Payment Gateways';
        $pg = \DB::table('payment_gateways')->get();
        return view('admin.payment-gateways', compact('pg', 'sys_menu'));
    }

    /* viewGateway  Function Start Here */
    public function viewGateway($name)
    {
        $sys_menu = 'Manage Payment Gateway';
        $pg = \DB::table('payment_gateways')->where('name', '=', $name)->first();
        return view('admin.payment-gateway-manage', compact('pg', 'sys_menu'));
    }

    /* updateGateway  Function Start Here */
    public function updateGateway(Request $request)
    {
        $v = \Validator::make($request->all(), [
            'value' => 'required', 'status' => 'required'
        ]);

        $name = \Input::get('cmd');


        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/payment-gateway-manage/' . $name)->with([
                'message' => 'This Option Is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        if ($v->fails()) {
            return redirect('admin/payment-gateway-manage/' . $name)->withErrors($v->errors());
        }

        $value = \Input::get('value');
        $extra_value = \Input::get('extra_value');
        $status = \Input::get('status');

        \DB::table('payment_gateways')->where('name', '=', $name)->update([
            'value' => $value,
            'extra_value' => $extra_value,
            'status' => $status
        ]);

        return redirect('admin/payment-gateway-manage/' . $name)->with([
            'message' => 'Gateway Update Successfully'
        ]);
    }


    /* emailTemplates  Function Start Here */
    public function emailTemplates()
    {
        $sys_menu = 'Email Templates';
        $d = \DB::table('email_templates')->get();

        return view('admin.email-templates', compact('d', 'sys_menu'));
    }

    /* manageTemplate  Function Start Here */
    public function manageTemplate($id)
    {
        $sys_menu = 'Manage Email Template';
        $d = \DB::table('email_templates')->find($id);
        return view('admin.email-templates-manage', compact('d', 'sys_menu'));
    }

    /* updateTemplate  Function Start Here */
    public function updateTemplate(Request $request)
    {
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/email-templates')->with([
                'message' => 'This Option Is Disable In Demo Mode',
                'message_important' => true
            ]);
        }

        $v = \Validator::make($request->all(), [
            'subject' => 'required', 'status' => 'required', 'message' => 'required'
        ]);

        $cmd = \Input::get('cmd');

        if ($v->fails()) {
            return redirect('admin/email-template-manage/' . $cmd)->withErrors($v->errors());
        }

        $subject = \Input::get('subject');
        $status = \Input::get('status');
        $message = \Input::get('message');

        \DB::table('email_templates')->where('id', '=', $cmd)->update([
            'subject' => $subject,
            'message' => $message,
            'status' => $status
        ]);

        return redirect('admin/email-template-manage/' . $cmd)->with([
            'message' => 'Email Template Update Successfully'
        ]);

    }


    /* updateSetting  Function Start Here */
    public function updateSetting(Request $request)
    {
        $appStage = app_config('AppStage');
        if ($appStage == 'Demo') {
            return redirect('admin/system-settings')->with([
                'message' => 'This Option Is Disable In Demo Mode',
                'message_important' => true
            ]);
        }


        $post_size = trim(ini_get('post_max_size'));

        $v = \Validator::make($request->all(), [
            'app_name' => 'required', 'app_title' => 'required', 'email' => 'required', 'footer' => 'required', 'maxupload' => 'required|numeric', 'promaxupload' => 'required|numeric', 'expiretime' => 'required'
        ]);

        if ($v->fails()) {
            return redirect('admin/system-settings')->withErrors($v->errors());
        }

        $destinationPath = public_path() . '/assets/img/';
        $save_path = 'assets/img/';

        $app_name = Input::get('app_name');
        $app_title = Input::get('app_title');
        $email = Input::get('email');
        $footer = Input::get('footer');
        $maxupload = Input::get('maxupload');
        $promaxupload = Input::get('promaxupload');
        $volume_type =strtolower($post_size[strlen($post_size)-1]);

        if($volume_type=='m'){
            $num_post_size=(int)$post_size;
        }elseif($volume_type=='g'){
            $pre=(int)$post_size;
            $num_post_size=$pre*1024;
        }else{
            return redirect('admin/system-settings')->with([
                'message' => 'You Can not set Post File Size More than 1048576MB',
                'message_important' => true
            ]);
        }

        if ($maxupload >= $num_post_size) {
            return redirect('admin/system-settings')->with([
                'message' => 'You System Support Max Post File Size ' . $post_size,
                'message_important' => true
            ]);
        }

        if ($promaxupload >= $num_post_size) {
            return redirect('admin/system-settings')->with([
                'message' => 'You System Support Max Post File Size ' . $post_size,
                'message_important' => true
            ]);
        }

        $expiretime = Input::get('expiretime');
        $eg = Input::get('eg');

        $app_logo = Input::file('app_logo');
        $app_fav = Input::file('app_fav');


        if ($app_name != '') {
            appconfig::where('setting', '=', 'AppName')->update(['value' => $app_name]);
        }

        if ($app_title != '') {
            appconfig::where('setting', '=', 'AppTitle')->update(['value' => $app_title]);
        }

        if ($email != '') {
            appconfig::where('setting', '=', 'Email')->update(['value' => $email]);
        }

        if ($footer != '') {
            appconfig::where('setting', '=', 'FooterTxt')->update(['value' => $footer]);
        }

        if ($maxupload != '') {
            appconfig::where('setting', '=', 'MaxUpload')->update(['value' => $maxupload]);
        }

        if ($promaxupload != '') {
            appconfig::where('setting', '=', 'ProMaxUpload')->update(['value' => $promaxupload]);
        }

        if ($expiretime != '') {
            appconfig::where('setting', '=', 'ExpireTime')->update(['value' => $expiretime]);
        }

        if ($eg != '') {
            appconfig::where('setting', '=', 'DefaultGateway')->update(['value' => $eg]);
        }

        if ($app_logo != '') {
            $app_logo_name = $app_logo->getClientOriginalName();
            Input::file('app_logo')->move($destinationPath, $app_logo_name);
            $or_path = $save_path . $app_logo_name;
            appconfig::where('setting', '=', 'AppLogo')->update(['value' => $or_path]);
        }


        if ($app_fav != '') {
            $app_fav_name = $app_fav->getClientOriginalName();
            Input::file('app_fav')->move($destinationPath, $app_fav_name);
            $or_path = $save_path . $app_fav_name;
            appconfig::where('setting', '=', 'AppFav')->update(['value' => $or_path]);
        }


        $storage_server = Input::get('storage_server');

        if($storage_server!=''){
            if ($storage_server == 'local') {

                $config_path = config_path() . '/filesystems.php';

                $exist = \File::exists($config_path);
                $storage_status = config('filesystems.default');

                if ($exist AND $storage_status != 'local') {

                    \File::delete($config_path);

                    $input = "<?php

                            return [

                                'default' => 'local',


                                'cloud' => 's3',

                                'disks' => [

                                    'local' => [
                                        'driver' => 'local',
                                        'root'   => storage_path().'/app',
                                    ],

                                    's3' => [
                                        'driver' => 's3',
                                        'key'    => 'your-key',
                                        'secret' => 'your-secret',
                                        'region' => 'your-region',
                                        'bucket' => 'your-bucket',
                                    ],

                                    'rackspace' => [
                                        'driver'    => 'rackspace',
                                        'username'  => 'your-username',
                                        'key'       => 'your-key',
                                        'container' => 'your-container',
                                        'endpoint'  => 'https://identity.api.rackspacecloud.com/v2.0/',
                                        'region'    => 'IAD',
                                        'url_type'  => 'publicURL'
                                    ],

                                ],

                            ];
                        ";


                    $fh = fopen($config_path, 'w') or die("can't create config file, your server does not support 'fopen' function, please create a file named - filesystems.php with following contents- <br/> $input");
                    fwrite($fh, $input);
                    fclose($fh);

                }
                appconfig::where('setting', '=', 'StorageServer')->update(['value' => 'local']);

            }
            else {

                $access_key = Input::get('access_key');
                $secret = Input::get('secret');
                $region = Input::get('region');
                $bucket = Input::get('bucket');


                $config_path = config_path() . '/filesystems.php';

                $exist = \File::exists($config_path);
                $storage_status = config('filesystems.default');

                if ($exist AND $storage_status != 's3') {

                    \File::delete($config_path);

                    $input = "<?php

                            return [

                                'default' => 's3',


                                'cloud' => 's3',

                                'disks' => [

                                    'local' => [
                                        'driver' => 'local',
                                        'root'   => storage_path().'/app',
                                    ],

                                    's3' => [
                                        'driver' => 's3',
                                        'key'    => '$access_key',
                                        'secret' => '$secret',
                                        'bucket' => '$bucket',
                                    ],

                                    'rackspace' => [
                                        'driver'    => 'rackspace',
                                        'username'  => 'your-username',
                                        'key'       => 'your-key',
                                        'container' => 'your-container',
                                        'endpoint'  => 'https://identity.api.rackspacecloud.com/v2.0/',
                                        'region'    => 'IAD',
                                        'url_type'  => 'publicURL'
                                    ],

                                ],

                            ];
                        ";


                    $fh = fopen($config_path, 'w') or die("can't create config file, your server does not support 'fopen' function, please create a file named - filesystems.php with following contents- <br/> $input");
                    fwrite($fh, $input);
                    fclose($fh);

                }

                appconfig::where('setting', '=', 'StorageServer')->update(['value' => 'aws']);
                appconfig::where('setting', '=', 'AWSAccessKey')->update(['value' => $access_key]);
                appconfig::where('setting', '=', 'AWSSecret')->update(['value' => $secret]);
                appconfig::where('setting', '=', 'AWSRegion')->update(['value' => $region]);
                appconfig::where('setting', '=', 'AWSBucket')->update(['value' => $bucket]);

            }

        }

        return redirect('admin/system-settings')->with([
            'message' => 'Setting Update Successfully'
        ]);


    }


    /* timeAutomation  Function Start Here */
    public function timeAutomation()
    {
        $sys_menu = 'Expire Time Automation';
        return view('admin.time-automation', compact('sys_menu'));
    }


    /* timeAutomationPost  Function Start Here */
    public function timeAutomationPost(Request $request)
    {
        $v = \Validator::make($request->all(), [
            'automation' => 'required'
        ]);

        if ($v->fails()) {
            return redirect('admin/time-automation')->withErrors($v->errors());
        }

        $automation = Input::get('automation');

        if ($automation == 'Yes') {
            if (app_config('Automation') == 'No') {

                $cur_time = date('Y-m-d H:m');
                $sdate = $cur_time . ":01";
                $tdate = $cur_time . ":59";

                appconfig::where('setting', '=', 'Automation')->update(['value' => 'Yes']);
                \DB::insert('SET GLOBAL EVENT_SCHEDULER = ON');
                \DB::unprepared(" CREATE EVENT delete_expired_file_data ON SCHEDULE EVERY 1 MINUTE
            DO
            UPDATE uploads SET expire='Yes' WHERE expire_time BETWEEN '$sdate' AND '$tdate' ");
            } else {
                return redirect('admin/time-automation')->with([
                    'message' => 'Update Successfully'
                ]);
            }
        } else {
            appconfig::where('setting', '=', 'Automation')->update(['value' => 'No']);
            \DB::insert('SET GLOBAL EVENT_SCHEDULER = 0');
            \DB::unprepared('DROP EVENT IF EXISTS delete_expired_file_data');
        }

        return redirect('admin/time-automation')->with([
            'message' => 'Update Successfully'
        ]);
    }


}